@@ -1,5 +1,5 @@
 //----------------------------------*-C++-*----------------------------------//
-// $Id: plstream.cc 8196 2008-01-30 15:59:12Z andrewross $
+// $Id: plstream.cc 9285 2009-01-08 23:46:45Z andrewross $
 // Geoffrey Furnish
 // Sep 21 1994
 //
@@ -441,10 +441,20 @@ void plstream::col( PLcolor c )
 
 // Set color, map 1.  Argument is a float between 0. and 1.
 
+void plstream::col1( PLFLT c )
+{
+    set_stream();
+
+    plcol1( c );
+}
+
+// Old (incorrect) version retained only for compatibility
 void plstream::col( PLFLT c )
 {
     set_stream();
 
+    cerr << "plstream::col(PLFLT c) : function deprecated. Use plstream::col1(PLFLT c) instead" << endl;
+
     plcol1( c );
 }
 
@@ -750,6 +760,15 @@ void plstream::gfnam( char *fnam )
     plgfnam(fnam);
 }
 
+// Get the current font family, style and weight
+
+void plstream::gfont( PLINT& family, PLINT& style, PLINT& weight )
+{
+    set_stream();
+
+    plgfont(&family, &style, &weight);
+}
+
 // Get current run level.
 
 void plstream::glevel(PLINT& level)
@@ -855,11 +874,11 @@ void plstream::gyax( PLINT& digmax, PLINT& digits )
 
 /* Get z axis labeling parameters */
 
-void plstream::gzax( PLINT *p_digmax, PLINT *p_digits )
+void plstream::gzax( PLINT& digmax, PLINT& digits )
 {
     set_stream();
 
-    plgzax(p_digmax, p_digits);
+    plgzax( &digmax, &digits );
 }
 
 /* Draws a histogram of n values of a variable in array data[0..n-1] */
@@ -1537,6 +1556,15 @@ void plstream::sfnam( const char *fnam )
     plsfnam(fnam);
 }
 
+// Set the current font family, style and weight
+
+void plstream::sfont( PLINT family, PLINT style, PLINT weight )
+{
+    set_stream();
+
+    plsfont(family, style, weight);
+}
+
 /* Shade region. */
 
 void
@@ -1915,7 +1943,8 @@ void plstream::stripd(PLINT id)
     plstripd(id);
 }
 
-/* plots a 2d image (or a matrix too large for plshade() ) */
+/* plots a 2d image (or a matrix too large for plshade() )  - colors
+ * automatically scaled */
 
 void plstream::image( PLFLT **data, PLINT nx, PLINT ny,
          PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT zmin, PLFLT zmax,
@@ -1927,6 +1956,20 @@ void plstream::image( PLFLT **data, PLINT nx, PLINT ny,
     	Dxmin, Dxmax, Dymin, Dymax);
 }
 
+/* plots a 2d image (or a matrix too large for plshade() ) */
+
+void plstream::imagefr( PLFLT **data, PLINT nx, PLINT ny,
+         PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT zmin, PLFLT zmax,
+        PLFLT valuemin, PLFLT valuemax,
+        void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
+        PLPointer pltr_data)
+{
+    set_stream();
+
+    plimagefr(data, nx, ny, xmin, xmax, ymin, ymax, zmin, zmax,
+    	valuemin, valuemax, pltr, pltr_data);
+}
+
 /* Set up a new line style */
 
 void plstream::styl( PLINT nms, PLINT *mark, PLINT *space )
@@ -2078,7 +2121,7 @@ void plstream::wind( PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax )
     plwind(xmin,xmax,ymin,ymax);
 }
 
-/*  set xor mode; mode = 1-enter, 0-leave, status = 0 if not interactive device
+/*  Set xor mode; mode = 1-enter, 0-leave, status = 0 if not interactive device
  */
 
 void plstream::xormod(bool mode, bool *status)
@@ -2104,6 +2147,24 @@ void plstream::xormod(PLINT mode, PLINT *status)
    *status = (PLINT) loc_status;
 }
 
+/* Set the seed for the random number generator included. */
+
+void plstream::seed(unsigned int s)
+{
+   set_stream();
+
+   plseed(s);
+}
+
+/* Returns a random number on [0,1]-interval. */
+
+PLFLT plstream::randd(void)
+{
+   set_stream();
+
+   return plrandd();
+}
+
 	/* The rest for use from C / C++ only */
 
 /* Returns a list of file-oriented device names and their menu strings */
@@ -2279,6 +2340,14 @@ void plstream::SetUsage( char *program_string, char *usage_string )
 
 /* Process input strings, treating them as an option and argument pair. */
 
+int plstream::setopt( const char *opt, const char *optarg )
+{
+    set_stream();
+
+    return ::plsetopt(opt, optarg);
+}
+
+// Depreciated version - use setopt instead.
 int plstream::SetOpt( const char *opt, const char *optarg )
 {
     set_stream();
