@@ -1,5 +1,5 @@
 //----------------------------------*-C++-*----------------------------------//
-// $Id: plstream.h 8196 2008-01-30 15:59:12Z andrewross $
+// $Id: plstream.h 9285 2009-01-08 23:46:45Z andrewross $
 // Geoffrey Furnish
 // Sep 21 1994
 //
@@ -50,13 +50,15 @@ class Contourable_Data {
     Contourable_Data( int nx, int ny ) : _nx(nx), _ny(ny) {}
     virtual void elements( int& nx, int& ny ) const { nx = _nx; ny=_ny; }
     virtual PLFLT operator()( int i, int j ) const =0;
+    virtual ~Contourable_Data() {};
 };
 
 PLFLT Contourable_Data_evaluator( PLINT i, PLINT j, PLPointer p );
 
-class Coord_Xformer {
+class PLDLLIMPEXP_CXX Coord_Xformer {
   public:
     virtual void xform( PLFLT ox, PLFLT oy, PLFLT& nx, PLFLT& ny ) const =0;
+    virtual ~Coord_Xformer() {};  
 };
 
 void Coord_Xform_evaluator( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer );
@@ -66,9 +68,10 @@ class Coord_2d {
     virtual PLFLT operator() ( int ix, int iy ) const =0;
     virtual void elements( int& _nx, int& _ny ) =0;
     virtual void min_max( PLFLT& _min, PLFLT& _max ) =0;
+    virtual ~Coord_2d() {};  
 };
 
-class PLDLLIMPEXP cxx_pltr2 : public Coord_Xformer {
+class PLDLLIMPEXP_CXX cxx_pltr2 : public Coord_Xformer {
     Coord_2d& xg;
     Coord_2d& yg;
   public:
@@ -82,7 +85,7 @@ class PLDLLIMPEXP cxx_pltr2 : public Coord_Xformer {
 // Cool stuff.
 //===========================================================================//
 
-class PLDLLIMPEXP plstream {
+class PLDLLIMPEXP_CXX plstream {
 
     PLINT stream;
 
@@ -108,7 +111,7 @@ class PLDLLIMPEXP plstream {
     plstream( PLINT nx /*=1*/, PLINT ny /*=1*/, PLINT r, PLINT g, PLINT b,
 	      const char *driver =NULL, const char *file =NULL );
 
-    ~plstream();
+    virtual ~plstream();
 
 // Now start miroring the PLplot C API.
 
@@ -173,6 +176,11 @@ class PLDLLIMPEXP plstream {
 
 // Set color, map 1.  Argument is a float between 0. and 1.
 
+    void col1( PLFLT c );
+
+// Previous function was inadvertently named plcol in old versions of p
+// lplot - this is maintained for backwards compatibility, but is best 
+// avoided in new code.
     void col( PLFLT c );
 
 // Draws a contour plot from data in f(nx,ny).  Is just a front-end to
@@ -315,7 +323,11 @@ class PLDLLIMPEXP plstream {
 
     void gfnam( char *fnam );
 
-/* Get the (current) run level.  */
+// Get the current font family, style and weight
+
+    void gfont(PLINT& family, PLINT& style, PLINT& weight);
+
+// Get the (current) run level. 
 
     void glevel( PLINT &p_level );
 
@@ -366,7 +378,7 @@ class PLDLLIMPEXP plstream {
 
 /* Get z axis labeling parameters */
 
-    void gzax( PLINT *p_digmax, PLINT *p_digits );
+    void gzax( PLINT& digmax, PLINT& digits );
 
 /* Draws a histogram of n values of a variable in array data[0..n-1] */
 
@@ -649,6 +661,10 @@ void pat( PLINT nlin, PLINT *inc, PLINT *del );
 
     void sfnam( const char *fnam );
 
+// Set the current font family, style and weight
+
+    void sfont(PLINT family, PLINT style, PLINT weight);
+
 /* Shade region. */
 
     void shade( PLFLT **a, PLINT nx, PLINT ny,
@@ -766,12 +782,21 @@ void spage( PLFLT xp, PLFLT yp, PLINT xleng, PLINT yleng,
 
     void stripd(PLINT id);
 
-/* plots a 2d image (or a matrix too large for plshade() ) */
+/* plots a 2d image (or a matrix too large for plshade() ) - colors 
+ * automatically scaled */
 
     void image( PLFLT **data, PLINT nx, PLINT ny,
            PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT zmin, PLFLT zmax,
            PLFLT Dxmin, PLFLT Dxmax, PLFLT Dymin, PLFLT Dymax);
 
+/* plots a 2d image (or a matrix too large for plshade() ) */
+
+    void imagefr( PLFLT **data, PLINT nx, PLINT ny,
+           PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT zmin, PLFLT zmax,
+           PLFLT valuemin, PLFLT valuemax, 
+           void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
+           PLPointer pltr_data);
+
 /* Set up a new line style */
 
     void styl( PLINT nms, PLINT *mark, PLINT *space );
@@ -841,8 +866,16 @@ void spage( PLFLT xp, PLFLT yp, PLINT xleng, PLINT yleng,
 
     void wind( PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax );
 
-/* set xor mode; mode = 1-enter, 0-leave, status = 0 if not interactive device */
+/* Set xor mode; mode = 1-enter, 0-leave, status = 0 if not interactive device */
     void xormod(bool mode, bool *status);
+    
+/* Random number generator based on Mersenne Twister.
+   Functions to set seed and obtain real random numbers in the range [0,1]. */
+
+    void seed(unsigned int s);
+
+    PLFLT randd(void);
+    
 
 	/* The rest for use from C only */
 
@@ -943,6 +976,10 @@ void spage( PLFLT xp, PLFLT yp, PLINT xleng, PLINT yleng,
 
 /* Process input strings, treating them as an option and argument pair. */
 
+    int setopt( const char *opt, const char *optarg );
+
+/* This version is for backward compatibility only - don't use in new code */
+
     int SetOpt( const char *opt, const char *optarg );
 
 /* Process options list using current options info. */
