@@ -1,4 +1,4 @@
-/* $Id: plstubs.h 8187 2008-01-29 17:24:29Z andrewross $
+/* $Id: plstubs.h 8953 2008-10-22 04:25:30Z arjenmarkus $
 
    Maurice LeBrun
    IFS, University of Texas
@@ -53,6 +53,7 @@
 #define STUB_U		3
 #define STUB_FORTRAN	4
 #define STUB_STDCALL	5
+#define STUB_MINGW	6
 
 #ifndef STUB_LINKAGE
 
@@ -99,6 +100,8 @@
 #define STUB_LINKAGE STUB_FORTRAN
 #elif defined(_MSC_VER)
 #define STUB_LINKAGE STUB_STDCALL
+#elif defined(__GNUC__)				/* GNU C with MinGW/Cygwin */
+#define STUB_LINKAGE STUB_MINGW
 #endif
 #elif defined(MSDOS)				/* MS-DOS based */
 #define STUB_LINKAGE STUB_FORTRAN
@@ -117,7 +120,7 @@
 \*----------------------------------------------------------------------*/
 
 #if STUB_LINKAGE==STUB_LAU
-#define FNAME(x,y)	y##_
+#define FNAME(x,y)	PLDLLIMPEXP_F77C y##_
 #define FNAME_(x,y)	y##_
 
 #elif STUB_LINKAGE == STUB_L
@@ -125,7 +128,7 @@
 #define FNAME_(x,y)	y
 
 #elif STUB_LINKAGE == STUB_U
-#define FNAME(x,y)	x
+#define FNAME(x,y)	PLDLLIMPEXP_F77C __stdcall x
 #define FNAME_(x,y)	x
 
 #elif STUB_LINKAGE == STUB_FORTRAN
@@ -133,9 +136,13 @@
 #define FNAME_(x,y)	x
 
 #elif STUB_LINKAGE == STUB_STDCALL
-#define FNAME(x,y)	PLDLLIMPEXP __stdcall x
+#define FNAME(x,y)	PLDLLIMPEXP_F77C __stdcall x
 #define FNAME_(x,y)	x
 
+#elif STUB_LINKAGE == STUB_MINGW
+#define FNAME(x,y)	PLDLLIMPEXP_F77C y##_
+#define FNAME_(x,y)	y
+
 #else
 #error "Illegal setting for STUB_LINKAGE"
 #endif
@@ -158,6 +165,7 @@
 #define    PL_SETCONTLABELFORMATa	FNAME(PL_SETCONTLABELFORMAT_,pl_setcontlabelformat_)
 #define    PL_SETCONTLABELPARAM		FNAME(PL_SETCONTLABELPARAM,pl_setcontlabelparam)
 #define    PL_SETCONTLABELPARAMa	FNAME(PL_SETCONTLABELPARAM_,pl_setcontlabelparam_)
+#define    PLABORT7	FNAME(PLABORT7,plabort7)
 #define    PLADV	FNAME(PLADV,pladv)
 #define    PLAXES7	FNAME(PLAXES7,plaxes7)
 #define    PLBIN	FNAME(PLBIN,plbin)
@@ -179,6 +187,7 @@
 #define    PLEND	FNAME(PLEND,plend)
 #define    PLEND1	FNAME(PLEND1,plend1)
 #define    PLENV	FNAME(PLENV,plenv)
+#define    PLENV0	FNAME(PLENV0,plenv0)
 #define    PLEOP	FNAME(PLEOP,pleop)
 #define    PLERRX	FNAME(PLERRX,plerrx)
 #define    PLERRY	FNAME(PLERRY,plerry)
@@ -192,13 +201,16 @@
 #define    PLGCOL0	FNAME(PLGCOL0,plgcol0)
 #define    PLGCOL0A	FNAME(PLGCOL0A,plgcol0a)
 #define    PLGCOLBG	FNAME(PLGCOLBG,plgcolbg)
+#define    PLGCOLBGA	FNAME(PLGCOLBGA,plgcolbga)
 #define    PLGCOMPRESSION	FNAME(PLGCOMPRESSION,plgcompression)
 #define    PLGDEV7	FNAME(PLGDEV7,plgdev7)
 #define    PLGDIDEV	FNAME(PLGDIDEV,plgdidev)
 #define    PLGDIORI	FNAME(PLGDIORI,plgdiori)
 #define    PLGDIPLT	FNAME(PLGDIPLT,plgdiplt)
 #define    PLGFAM	FNAME(PLGFAM,plgfam)
+#define    PLGFCI       FNAME(PLGFCI,plgfci)
 #define    PLGFNAM7	FNAME(PLGFNAM7,plgfnam7)
+#define    PLGFONT	FNAME(PLGFONT,plgfont)
 #define    PLGLEVEL	FNAME(PLGLEVEL,plglevel)
 #define    PLGPAGE	FNAME(PLGPAGE,plgpage)
 #define    PLGRA	FNAME(PLGRA,plgra)
@@ -212,25 +224,31 @@
 #define    PLGYAX	FNAME(PLGYAX,plgyax)
 #define    PLGZAX	FNAME(PLGZAX,plgzax)
 #define    PLHIST	FNAME(PLHIST,plhist)
-#define    PLHLS        FNAME(PLHLS,plhls)
-#define    PLHLSRGB     FNAME(PLHLSRGB,plhlsrgb)
-#define    PLINIT       FNAME(PLINIT,plinit)
+#define    PLHLS	FNAME(PLHLS,plhls)
+#define    PLHLSRGB	FNAME(PLHLSRGB,plhlsrgb)
+#define    PLIMAGE	FNAME(PLIMAGE,plimage)
+#define    PLIMAGEFR07	FNAME(PLIMAGEFR07,plimagefr07)
+#define    PLIMAGEFR17	FNAME(PLIMAGEFR17,plimagefr17)
+#define    PLIMAGEFR27	FNAME(PLIMAGEFR27,plimagefr27)
+#define    PLIMAGEFR7	FNAME(PLIMAGEFR7,plimagefr7)
+#define    PLINIT	FNAME(PLINIT,plinit)
 #define    PLJOIN	FNAME(PLJOIN,pljoin)
 #define    PLLAB7	FNAME(PLLAB7,pllab7)
 #define    PLLIGHTSOURCE	FNAME(PLLIGHTSOURCE,pllightsource)
 #define    PLLINE	FNAME(PLLINE,plline)
 #define    PLLINE3	FNAME(PLLINE3,plline3)
 #define    PLLSTY	FNAME(PLLSTY,pllsty)
-#define    PLMAPC	FNAME(PLMAPC,plmapc)
-#define    PLMERIDIANSC	FNAME(PLMERIDIANSC,plmeridiansc)
+#define    PLMAP7	FNAME(PLMAP7,plmap7)
+#define    PLMERIDIANS7	FNAME(PLMERIDIANS7,plmeridians7)
 #define    PLMESH	FNAME(PLMESH,plmesh)
 #define    PLMESHC	FNAME(PLMESHC,plmeshc)
 #define    PLMKSTRM	FNAME(PLMKSTRM,plmkstrm)
 #define    PLMTEX7	FNAME(PLMTEX7,plmtex7)
 #define    PLMTEX37	FNAME(PLMTEX37,plmtex37)
 #define    PLOT3D	FNAME(PLOT3D,plot3d)
-#define    PLOT3DC_	FNAME_(PLOT3DC_,plot3dc_)
-#define    PLOT3DC	FNAME(PLOT3DC_,plot3dc_)
+#define    PLOT3DC_	FNAME_(PLOT3DC,plot3dc)
+#define    PLOT3DC	FNAME(PLOT3DC,plot3dc)
+#define    PLOT3DCL	FNAME(PLOT3DCL,plot3dcl)
 #define    PLPARSEOPTS7	FNAME(PLPARSEOPTS7,plparseopts7)
 #define    PLPAT	FNAME(PLPAT,plpat)
 #define    PLPOIN	FNAME(PLPOIN,plpoin)
@@ -240,6 +258,7 @@
 #define    PLPSTY	FNAME(PLPSTY,plpsty)
 #define    PLPTEX7	FNAME(PLPTEX7,plptex7)
 #define    PLPTEX37	FNAME(PLPTEX37,plptex37)
+#define    PLRANDD	FNAME(PLRANDD,plrandd)
 #define    PLREPLOT	FNAME(PLREPLOT,plreplot)
 #define    PLRGB	FNAME(PLRGB,plrgb)
 #define    PLRGB1	FNAME(PLRGB1,plrgb1)
@@ -265,11 +284,13 @@
 #define    PLSDIORI	FNAME(PLSDIORI,plsdiori)
 #define    PLSDIPLT	FNAME(PLSDIPLT,plsdiplt)
 #define    PLSDIPLZ	FNAME(PLSDIPLZ,plsdiplz)
+#define    PLSEED       FNAME(PLSEED,plseed)
 #define    PLSESC	FNAME(PLSESC,plsesc)
-#define    PLSETMAPFORMC	FNAME(PLSETMAPFORMC,plsetmapformc)
 #define    PLSETOPT7	FNAME(PLSETOPT7,plsetopt7)
 #define    PLSFAM	FNAME(PLSFAM,plsfam)
+#define    PLSFCI       FNAME(PLSFCI,plsfci)
 #define    PLSFNAM7	FNAME(PLSFNAM7,plsfnam7)
+#define    PLSFONT	FNAME(PLSFONT,plsfont)
 #define    PLSHADE07	FNAME(PLSHADE07,plshade07)
 #define    PLSHADE17	FNAME(PLSHADE17,plshade17)
 #define    PLSHADE27	FNAME(PLSHADE27,plshade27)
@@ -286,6 +307,7 @@
 #define    PLSPAUSE	FNAME(PLSPAUSE,plspause)
 #define    PLSSTRM	FNAME(PLSSTRM,plsstrm)
 #define    PLSSUB	FNAME(PLSSUB,plssub)
+#define    PLSURF3D	FNAME(PLSURF3D,plsurf3d)
 #define    PLSSYM	FNAME(PLSSYM,plssym)
 #define    PLSTAR	FNAME(PLSTAR,plstar)
 #define    PLSTART7	FNAME(PLSTART7,plstart7)
