@@ -1,4 +1,4 @@
-/* $Id: sc3d.c 7112 2006-10-23 19:56:05Z arjenmarkus $
+/* $Id: sc3d.c 8953 2008-10-22 04:25:30Z arjenmarkus $
 
 	Stub routines for 3d plots.
 
@@ -25,7 +25,7 @@
 #include "plstubs.h"
 
 void
-PLOT3DC(PLFLT *x, PLFLT *y, PLFLT *z,
+PLOT3DC__(PLFLT *x, PLFLT *y, PLFLT *z,
 	PLINT *nx, PLINT *ny, PLINT *opt,
 	PLFLT *clevel, PLINT *nlevel, PLINT *lx)
 {
@@ -47,6 +47,14 @@ PLOT3DC(PLFLT *x, PLFLT *y, PLFLT *z,
 
 }
 
+void
+PLOT3DC(PLFLT *x, PLFLT *y, PLFLT *z,
+        PLINT *nx, PLINT *ny, PLINT *opt,
+        PLFLT *clevel, PLINT *nlevel, PLINT *lx)
+{
+    PLOT3DC__(x, y, z, nx, ny, opt, clevel, nlevel, lx);
+}
+
 void
 PLSURF3D(PLFLT *x, PLFLT *y, PLFLT *z,
        PLINT *nx, PLINT *ny, PLINT *opt,
@@ -97,7 +105,7 @@ PLMESH(PLFLT *x, PLFLT *y, PLFLT *z,
    PLFLT clevel = 0.;
 
    optlocal = *opt | MESH;
-   CALL_PLOT3DC(x, y, z, nx, ny, &optlocal, &clevel, &nlevel, lx);
+   PLOT3DC__(x, y, z, nx, ny, &optlocal, &clevel, &nlevel, lx);
 }
 
 void
@@ -107,7 +115,7 @@ PLMESHC(PLFLT *x, PLFLT *y, PLFLT *z,
 {
    PLINT optlocal;
    optlocal = *opt | MESH;
-   CALL_PLOT3DC(x, y, z, nx, ny, &optlocal, clevel, nlevel, lx);
+   PLOT3DC__(x, y, z, nx, ny, &optlocal, clevel, nlevel, lx);
 }
 
 
@@ -119,6 +127,6 @@ PLOT3D(PLFLT *x, PLFLT *y, PLFLT *z,
    PLFLT clevel = 0.;
 
    optlocal = *opt | (*side != 0 ? DRAW_SIDES : 0);
-   CALL_PLOT3DC(x, y, z, nx, ny, &optlocal, &clevel, &nlevel, lx);
+   PLOT3DC__(x, y, z, nx, ny, &optlocal, &clevel, &nlevel, lx);
 }
 
