@@ -1,4 +1,4 @@
-/* $Id: scstubs.c 8164 2008-01-23 10:59:02Z andrewross $
+/* $Id: scstubs.c 9278 2009-01-08 14:30:16Z andrewross $
 
 	C stub routines.
 
@@ -56,6 +56,12 @@ PL_SETCONTLABELPARAMa(PLFLT *offset, PLFLT *size, PLFLT *spacing, PLINT *active)
     c_pl_setcontlabelparam(*offset, *size, *spacing, *active);
 }
 
+void
+PLABORT7(const char *text)
+{
+    plabort(text);
+}
+
 void
 PLADV(PLINT *sub)
 {
@@ -161,6 +167,13 @@ PLENV(PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
     c_plenv(*xmin, *xmax, *ymin, *ymax, *just, *axis);
 }
 
+void
+PLENV0(PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
+       PLINT *just, PLINT *axis)
+{
+    c_plenv0(*xmin, *xmax, *ymin, *ymax, *just, *axis);
+}
+
 void
 PLEOP(void)
 {
@@ -275,18 +288,41 @@ PLGDIPLT(PLFLT *p_xmin, PLFLT *p_ymin, PLFLT *p_xmax, PLFLT *p_ymax)
     c_plgdiplt(p_xmin, p_ymin, p_xmax, p_ymax);
 }
 
+void
+PLGETCURSOR(PLGraphicsIn *gin)
+{
+  plGetCursor(gin);
+}
+
 void
 PLGFAM(PLINT *fam, PLINT *num, PLINT *bmax)
 {
     c_plgfam(fam, num, bmax);
 }
 
+/* Note: Fortran does not have unsigned integers so we need to use a
+ * 64 bit signed integer which corresponds to a fortran integer*8
+ * in order to contain the number.  */
+void
+PLGFCI(PLINT64 *pfci)
+{
+    PLUNICODE fci;
+    c_plgfci(&fci);
+    *pfci = (PLINT64) fci;
+}
+
 void
 PLGFNAM7(char *fnam, int length)
 {
     c_plgfnam(fnam);
 }
 
+void
+PLGFONT(PLINT *family, PLINT *style, PLINT *weight)
+{
+    c_plgfont(family, style, weight);
+}
+
 void
 PLGLEVEL(PLINT *level)
 {
@@ -385,6 +421,56 @@ PLHLSRGB(PLFLT *h, PLFLT *l, PLFLT *s, PLFLT *r, PLFLT *g, PLFLT *b)
     c_plhlsrgb(*h, *l, *s, r, g, b);
 }
 
+#if 0
+void
+PLIMAGEFR(PLFLT *idata, PLINT *nx, PLINT *ny,
+          PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax, PLFLT *zmin, PLFLT *zmax,
+          PLFLT *Dxmin, PLFLT *Dxmax, PLFLT *Dymin, PLFLT *Dymax,
+          PLFLT *valuemin, PLFLT *valuemax)
+{
+    int   i, j;
+    PLFLT **pidata;
+
+    plAlloc2dGrid(&pidata, *nx, *ny);
+
+    for ( i = 0 ; i < *nx ; i ++ ) {
+        for ( j = 0 ; j < *ny ; j ++ ) {
+            pidata[i][j] = idata[i + j * (*nx)];
+        }
+    }
+
+    c_plimagefr(pidata, *nx, *ny,
+         *xmin, *xmax, *ymin, *ymax, *zmin, *zmax,
+         *Dxmin, *Dxmax, *Dymin, *Dymax,
+         *valuemin, *valuemax);
+
+    plFree2dGrid(pidata, *nx, *ny);
+}
+#endif
+
+void
+PLIMAGE(PLFLT *idata, PLINT *nx, PLINT *ny,
+          PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax, PLFLT *zmin, PLFLT *zmax,
+          PLFLT *Dxmin, PLFLT *Dxmax, PLFLT *Dymin, PLFLT *Dymax)
+{
+    int   i, j;
+    PLFLT **pidata;
+
+    plAlloc2dGrid(&pidata, *nx, *ny);
+
+    for ( i = 0 ; i < *nx ; i ++ ) {
+        for ( j = 0 ; j < *ny ; j ++ ) {
+            pidata[i][j] = idata[i + j * (*nx)];
+        }
+    }
+
+    c_plimage(pidata, *nx, *ny,
+         *xmin, *xmax, *ymin, *ymax, *zmin, *zmax,
+         *Dxmin, *Dxmax, *Dymin, *Dymax);
+
+    plFree2dGrid(pidata, *nx, *ny);
+}
+
 void
 PLINIT(void)
 {
@@ -434,7 +520,7 @@ plmapf2c( PLINT n, PLFLT *x, PLFLT *y )
 }
 
 void
-PLMAPC( const char *type,
+PLMAP7( const char *type,
         PLFLT *minlong, PLFLT *maxlong, PLFLT *minlat, PLFLT *maxlat )
 
 {
@@ -443,7 +529,7 @@ PLMAPC( const char *type,
 
 
 void
-PLMERIDIANSC( PLFLT *dlong, PLFLT *dlat,
+PLMERIDIANS7( PLFLT *dlong, PLFLT *dlat,
               PLFLT *minlong, PLFLT *maxlong, PLFLT *minlat, PLFLT *maxlat )
 {
     c_plmeridians(plmapf2c, *dlong, *dlat, *minlong, *maxlong, *minlat, *maxlat);
@@ -528,7 +614,7 @@ PLPTEX7(PLFLT *x, PLFLT *y, PLFLT *dx, PLFLT *dy, PLFLT *just, const char *text)
 
 void
 PLPTEX37(
-	 PLFLT *x, PLFLT *y, PLFLT *z, 
+	 PLFLT *x, PLFLT *y, PLFLT *z,
 	 PLFLT *dx, PLFLT *dy, PLFLT *dz,
 	 PLFLT *sx, PLFLT *sy, PLFLT *sz,
 	 PLFLT *just, const char *text)
@@ -536,6 +622,12 @@ PLPTEX37(
     c_plptex3(*x, *y, *z, *dx, *dy, *dz, *sx, *sy, *sz, *just, text);
 }
 
+PLFLT
+PLRANDD()
+{
+    return c_plrandd();
+}
+
 void
 PLREPLOT(void)
 {
@@ -704,12 +796,21 @@ PLSDIPLZ(PLFLT *xmin, PLFLT *ymin, PLFLT *xmax, PLFLT *ymax)
     c_plsdiplz(*xmin, *ymin, *xmax, *ymax);
 }
 
+void
+PLSEED(unsigned int *s)
+{
+    c_plseed(*s);
+}
+
 void
 PLSESC(PLINT *esc)
 {
     c_plsesc((char) *esc);
 }
 
+/* Auxiliary routine - not to be used publicly
+*/
+#define    PLSETMAPFORMC	FNAME(PLSETMAPFORMC,plsetmapformc)
 void
 PLSETMAPFORMC( void (*mapform)(PLINT *, PLFLT *, PLFLT *) )
 {
@@ -728,12 +829,30 @@ PLSFAM(PLINT *fam, PLINT *num, PLINT *bmax)
     c_plsfam(*fam, *num, *bmax);
 }
 
+/* Note: Fortran does not have unsigned integers so we need to use a
+ * 64 bit signed integer which corresponds to a fortran integer*8
+ * in order to contain the number.  */
+/* PLSFCI(PLINT64 *fci) */
+void
+PLSFCI(PLINT64 *fci)
+{
+    PLUNICODE f;
+    f = (PLUNICODE) (*fci & 0xffffffff);
+    c_plsfci(f);
+}
+
 void
 PLSFNAM7(const char *fnam)
 {
     c_plsfnam(fnam);
 }
 
+void
+PLSFONT(PLINT *family, PLINT *style, PLINT *weight)
+{
+    c_plsfont(*family, *style, *weight);
+}
+
 void
 PLSMAJ(PLFLT *def, PLFLT *scale)
 {
@@ -814,7 +933,7 @@ PLSTRIPC(PLINT *id, const char *xspec, const char *yspec,
 	  PLBOOL *y_ascl, PLBOOL *acc,
 	  PLINT *colbox, PLINT *collab,
 	  PLINT *colline, PLINT *styline,
-	  const char *legline0, const char *legline1, 
+	  const char *legline0, const char *legline1,
           const char *legline2, const char *legline3,
 	  const char *labx, const char *laby, const char *labtop)
 {
