@@ -1,5 +1,5 @@
 !***********************************************************************
-!  $Id: sfstubs.f90 8164 2008-01-23 10:59:02Z andrewross $
+!  $Id: sfstubs.f90 8578 2008-07-24 13:11:19Z andrewross $
 !  sfstubs.f
 !
 !  Copyright (C) 2004  Alan W. Irwin
@@ -51,6 +51,21 @@
 
       end subroutine
 
+!***********************************************************************
+
+      subroutine plabort(text)
+
+      implicit none
+      character*(*) text
+
+      include 'sfstubs.h'
+
+      call plstrf2c(text, string1, maxlen)
+      s1 = transfer( string1, s1 )
+      call plabort7(s1)
+
+      end subroutine
+
 !***********************************************************************
 
       subroutine plsdev(dnam)
@@ -573,6 +588,67 @@
 
       end subroutine
 
+!***********************************************************************
+
+      subroutine plimagefr_0(z,xmin,xmax,ymin,ymax,zmin,zmax, &
+           valuemin,valuemax)
+
+      implicit none
+      integer nx, ny, lx
+      real(kind=plflt) z(:,:)
+      real(kind=plflt) xmin, xmax, ymin, ymax, zmin, zmax, valuemin, valuemax
+
+      call plimagefr07(z,size(z,1),size(z,2),xmin,xmax,ymin,ymax,zmin,zmax, &
+          valuemin,valuemax,size(z,1))
+
+      end subroutine
+
+!***********************************************************************
+
+      subroutine plimagefr_1(z,xmin,xmax,ymin,ymax,zmin,zmax, &
+           valuemin,valuemax,xg,yg)
+
+      implicit none
+      integer nx, ny, lx
+      real(kind=plflt) z(:,:), xg(:), yg(:)
+      real(kind=plflt) xmin, xmax, ymin, ymax, zmin, zmax, valuemin, valuemax
+
+      call plimagefr17(z,size(z,1),size(z,2),xmin,xmax,ymin,ymax,zmin,zmax, &
+          valuemin,valuemax,xg,yg,size(z,1))
+
+      end subroutine
+
+!***********************************************************************
+
+      subroutine plimagefr_2(z,xmin,xmax,ymin,ymax,zmin,zmax, &
+           valuemin,valuemax,xg,yg)
+
+      implicit none
+      integer nx, ny, lx
+      real(kind=plflt) z(:,:), xg(:,:), yg(:,:)
+      real(kind=plflt) xmin, xmax, ymin, ymax, zmin, zmax, valuemin, valuemax
+
+      call plimagefr27(z,size(z,1),size(z,2),xmin,xmax,ymin,ymax,zmin,zmax, &
+          valuemin,valuemax,xg,yg,size(z,1))
+
+      end subroutine
+
+!***********************************************************************
+
+      subroutine plimagefr_tr(z,xmin,xmax,ymin,ymax,zmin,zmax, &
+           valuemin,valuemax,tr)
+
+      implicit none
+      integer nx, ny, lx
+      real(kind=plflt) z(:,:)
+      real(kind=plflt) xmin, xmax, ymin, ymax, zmin, zmax, valuemin, valuemax
+      real(kind=plflt) tr(6)
+
+      call plimagefr7(z,size(z,1),size(z,2),xmin,xmax,ymin,ymax,zmin,zmax, &
+           valuemin,valuemax,tr,size(z,1))
+
+      end  subroutine
+
 !***********************************************************************
 
       subroutine pllab(xlab,ylab,title)
@@ -697,7 +773,7 @@
 
       call plsetmapformc(mapform)
       s1 = transfer( string1, s1 )
-      call plmapc(s1,minx,maxx,miny,maxy)
+      call plmap7(s1,minx,maxx,miny,maxy)
 
       end subroutine
 
@@ -713,7 +789,7 @@
       include 'sfstubs.h'
 
       call plsetmapformc(mapform)
-      call plmeridiansc(dlong,dlat,minlong,maxlong,minlat,maxlat)
+      call plmeridians7(dlong,dlat,minlong,maxlong,minlat,maxlat)
 
       end subroutine
 
@@ -722,7 +798,7 @@
       subroutine pltimefmt(fmt)
 
       implicit none
-      character*(*) fmt 
+      character*(*) fmt
 
       include 'sfstubs.h'
 
