@@ -311,11 +311,21 @@ public void gfam(int[] fam, int[] num, int[]  bmax) {
     plplotjavac.plgfam(fam, num, bmax);
 }
 
+public void gfci(long[] pfci) {
+    if (set_stream() == -1) return;
+    plplotjavac.plgfci(pfci);
+}
+
 public void gfnam(StringBuffer fnam) {
     if (set_stream() == -1) return;
     plplotjavac.plgfnam(fnam);
 }
 
+public void gfont(int[] family, int[] style, int[] weight) {
+    if (set_stream() == -1) return;
+    plplotjavac.plgfont(family, style, weight);
+}
+
 public void glevel(int[] p_level) {
     if (set_stream() == -1) return;
     plplotjavac.plglevel(p_level);
@@ -384,16 +394,22 @@ public void hist(double[] data, double datmin, double datmax, int nbin, int oldw
     plplotjavac.plhist(data, datmin, datmax, nbin, oldwin);
 }
 
-public void hls(double h, double l, double s) {
-    if (set_stream() == -1) return;
-    plplotjavac.plhls(h, l, s);
-}
+// Officially deprecated.
+//public void hls(double h, double l, double s) {
+//    if (set_stream() == -1) return;
+//    plplotjavac.plhls(h, l, s);
+//}
 
 public void image(double[][] data, double xmin, double xmax, double ymin, double ymax, double zmin, double zmax, double Dxmin, double Dxmax, double Dymin, double Dymax) {
     if (set_stream() == -1) return;
     plplotjavac.plimage(data, xmin, xmax, ymin, ymax, zmin, zmax, Dxmin, Dxmax, Dymin, Dymax);
 }
 
+public void imagefr(double[][] data, double xmin, double xmax, double ymin, double ymax, double zmin, double zmax, double valuemin, double valuemax, double[][] pltr_im, double[][] OBJECT_DATA_im) {
+    if (set_stream() == -1) return;
+    plplotjavac.plimagefr(data, xmin, xmax, ymin, ymax, zmin, zmax, valuemin, valuemax, pltr_im, OBJECT_DATA_im);
+}
+
 public void init() {
     if (set_stream() == -1) return;
     plplotjavac.plinit();
@@ -429,6 +445,16 @@ public void lsty(int lin) {
     plplotjavac.pllsty(lin);
 }
 
+public void map(PLCallback mapform, String type, double minlong, double maxlong, double minlat, double maxlat) {
+    if (set_stream() == -1) return;
+    plplotjavac.plmap(mapform, type, minlong, maxlong, minlat, maxlat);
+}
+
+public void meridians(PLCallback mapform, double dlong, double dlat, double minlong, double maxlong, double minlat, double maxlat) {
+    if (set_stream() == -1) return;
+    plplotjavac.plmeridians(mapform, dlong, dlat, minlong, maxlong, minlat, maxlat);
+}
+
 public void minMax2dGrid(double[][]f, double[] fmax, double[] fmin) {
     if (set_stream() == -1) return;
     plplotjavac.plMinMax2dGrid(f,fmax,fmin);
@@ -533,6 +559,11 @@ public void ptex3(double x, double y, double z, double dx, double dy, double dz,
     plplotjavac.plptex3(x, y, z, dx, dy, dz, sx, sy, sz, just, text);
 }
 
+public double randd() {
+    if (set_stream() == -1) return 0.0;
+    return plplotjavac.plrandd();
+}
+
 public void replot() {
     if (set_stream() == -1) return;
     plplotjavac.plreplot();
@@ -658,6 +689,11 @@ public void sdiplz(double xmin, double ymin, double xmax, double ymax) {
     plplotjavac.plsdiplz(xmin, ymin, xmax, ymax);
 }
 
+public void seed(long s) {
+    if (set_stream() == -1) return;
+    plplotjavac.plseed(s);
+}
+
 public void sesc(char esc) {
     if (set_stream() == -1) return;
     plplotjavac.plsesc(esc);
@@ -673,11 +709,21 @@ public void sfam(int fam, int num, int bmax) {
     plplotjavac.plsfam(fam, num, bmax);
 }
 
+public void sfci(long fci) {
+    if (set_stream() == -1) return;
+    plplotjavac.plsfci(fci);
+}
+
 public void sfnam(String fnam) {
     if (set_stream() == -1) return;
     plplotjavac.plsfnam(fnam);
 }
 
+public void sfont(int family, int style, int weight) {
+    if (set_stream() == -1) return;
+    plplotjavac.plsfont(family, style, weight);
+}
+
 public void shades( double[][] a, double xmin, double xmax, double ymin,
 		double ymax, double[] clevel, int fill_width, int cont_color,
 		int cont_width, boolean rectangular, 
