@@ -15,8 +15,10 @@
     
 function p10
 
-  t = automatic_replot;
-  automatic_replot = 0;
+  if (exist("automatic_replot"))
+    t = automatic_replot;
+    automatic_replot = 0;
+  endif
 
   title("Comet");
   xlabel "";
@@ -24,7 +26,9 @@ function p10
   t = -pi:pi/200:0;
   comet(t,tan(sin(t))-sin(tan(t)));
   
-  automatic_replot = t;
+  if (exist("automatic_replot"))
+    automatic_replot = t;
+  endif
 
 endfunction
 
