@@ -90,7 +90,7 @@ static PyMethodDef plplot_widget_methods[] = {
     {NULL, NULL, 0, NULL}
 };
 
-void initplplot_widget(void)
+PLDLLIMPEXP_PLPLOT_WIDGETMODULE void initplplot_widget(void)
 {
     PyObject *m;
     PyObject *d;
