@@ -1,4 +1,4 @@
-/* $Id: tclAPI.c 8186 2008-01-29 10:50:48Z andrewross $
+/* $Id: tclAPI.c 9324 2009-01-16 11:12:39Z andrewross $
 
     Copyright 1994, 1995
     Maurice LeBrun			mjl@dino.ph.utexas.edu
@@ -31,7 +31,6 @@
     driver, in principle.
 */
 
-#define USINGPLDLL
 #include "plplotP.h"
 #include "pltcl.h"
 #ifndef __WIN32__
@@ -62,6 +61,11 @@ static int plshadesCmd	(ClientData, Tcl_Interp *, int, const char **);
 static int plmapCmd	(ClientData, Tcl_Interp *, int, const char **);
 static int plmeridiansCmd (ClientData, Tcl_Interp *, int, const char **);
 static int plvectCmd   (ClientData, Tcl_Interp *, int, const char **);
+static int plranddCmd  (ClientData, Tcl_Interp *, int, const char **);
+static int plgriddataCmd  (ClientData, Tcl_Interp *, int, const char **);
+static int plimageCmd  (ClientData, Tcl_Interp *, int, const char **);
+static int plimagefrCmd(ClientData, Tcl_Interp *, int, const char **);
+static int plstripcCmd (ClientData, Tcl_Interp *, int, const char **);
 
 /*
  * The following structure defines all of the commands in the PLplot/Tcl
@@ -100,6 +104,11 @@ static CmdInfo Cmds[] = {
     {"plshade",		plshadeCmd},
     {"plshades",	plshadesCmd},
     {"plvect",         plvectCmd},
+    {"plrandd",        plranddCmd},
+    {"plgriddata",     plgriddataCmd},
+    {"plimage",        plimageCmd},
+    {"plimagefr",      plimagefrCmd},
+    {"plstripc",       plstripcCmd},
     {NULL,		NULL}
 };
 
@@ -119,8 +128,7 @@ static char errmsg[160];
 #define PL_LIBRARY ""
 #endif
 
-/* extern char PLDLLIMPEXP * plplotLibDir; */
-extern char PLDLLIMPORT * plplotLibDir;
+extern PLDLLIMPORT char * plplotLibDir;
 
 #if (!defined(MAC_TCL) && !defined(__WIN32__))
 /*
@@ -510,12 +518,16 @@ PlbasicInit( Tcl_Interp *interp )
  * interfacing to PLplot.  Should not be used in a widget-based system.
 \*--------------------------------------------------------------------------*/
 
-int PLDLLEXPORT
+int
 Pltcl_Init( Tcl_Interp *interp )
 {
     register CmdInfo *cmdInfoPtr;
 /* This must be before any other Tcl related calls */
     if (PlbasicInit(interp) != TCL_OK) {
+	Tcl_AppendResult(interp, "Could not find plplot.tcl - please set \
+environment variable PL_LIBRARY to the directory containing that file",
+	(char *) NULL);
+
 	return TCL_ERROR;
     }
 
@@ -2214,6 +2226,26 @@ plsurf3dCmd( ClientData clientData, Tcl_Interp *interp,
     return TCL_OK;
 }
 
+/*--------------------------------------------------------------------------*\
+ * plranddCmd
+ *
+ * Return a random number
+\*--------------------------------------------------------------------------*/
+
+static int
+plranddCmd(ClientData clientData, Tcl_Interp *interp,
+	     int argc, const char **argv)
+{
+    if (argc != 1) {
+	Tcl_AppendResult(interp, "wrong # args: ",
+			 argv[0], " takes no arguments", (char *) NULL);
+	return TCL_ERROR;
+    } else {
+	Tcl_SetObjResult(interp, Tcl_NewDoubleObj(plrandd()));
+	return TCL_OK;
+    }
+}
+
 /*--------------------------------------------------------------------------*\
  * plsetoptCmd
  *
@@ -2792,18 +2824,68 @@ plshadesCmd( ClientData clientData, Tcl_Interp *interp,
  * x[], y[] are the coordinates to be plotted.
 \*--------------------------------------------------------------------------*/
 
+static const char *transform_name;   /* Name of the procedure that transforms the
+                                  coordinates */
+static Tcl_Interp *tcl_interp; /* Pointer to the current interp */
+static int return_code;        /* Saved return code */
+
 void
 mapform(PLINT n, PLFLT *x, PLFLT *y)
 {
     int i;
-    double xp, yp, radius;
-    for (i = 0; i < n; i++) {
-	radius = 90.0 - y[i];
-	xp = radius * cos(x[i] * PI / 180.0);
-	yp = radius * sin(x[i] * PI / 180.0);
-	x[i] = xp;
-	y[i] = yp;
+    char *cmd;
+    tclMatrix *xPtr, *yPtr;
+
+    cmd = (char *) malloc( strlen(transform_name) + 40);
+
+    /* Build the (new) matrix commands and fill the matrices */
+    sprintf(cmd, "matrix %cx f %d", (char)1, n);
+    if (Tcl_Eval(tcl_interp, cmd) != TCL_OK) {
+        return_code = TCL_ERROR;
+        free(cmd);
+        return;
     }
+    sprintf(cmd, "matrix %cy f %d", (char)1, n);
+    if (Tcl_Eval(tcl_interp, cmd) != TCL_OK) {
+        return_code = TCL_ERROR;
+        free(cmd);
+        return;
+    }
+
+    sprintf(cmd, "%cx", (char)1);
+    xPtr = Tcl_GetMatrixPtr(tcl_interp, cmd);
+    sprintf(cmd, "%cy", (char)1);
+    yPtr = Tcl_GetMatrixPtr(tcl_interp, cmd);
+
+    if (xPtr == NULL || yPtr == NULL ) return; /* Impossible, but still */
+
+    for (i = 0; i < n; i++) {
+       xPtr->fdata[i] = x[i];
+       yPtr->fdata[i] = y[i];
+    }
+
+    /* Now call the Tcl procedure to do the work */
+    sprintf(cmd, "%s %d %cx %cy", transform_name, n, (char)1, (char)1);
+    return_code = Tcl_Eval(tcl_interp, cmd);
+    if (return_code != TCL_OK) {
+        free(cmd);
+        return;
+    }
+
+    /* Don't forget to copy the results back into the original arrays
+    */
+    for (i = 0; i < n; i++) {
+       x[i] = xPtr->fdata[i] ;
+       y[i] = yPtr->fdata[i] ;
+    }
+
+    /* Clean up, otherwise the next call will fail - [matrix] does not
+       overwrite existing commands
+    */
+    sprintf(cmd, "rename %cx {}; rename %cy {}", (char)1, (char)1);
+    return_code = Tcl_Eval(tcl_interp, cmd);
+
+    free(cmd);
 }
 
 /*--------------------------------------------------------------------------*\
@@ -2822,27 +2904,47 @@ plmapCmd( ClientData clientData, Tcl_Interp *interp,
 {
     PLFLT minlong, maxlong, minlat, maxlat;
     PLINT transform;
+    PLINT idxname;
 
-    if (argc < 7 ) {
+    return_code = TCL_OK;
+    if (argc < 6 || argc > 7) {
 	Tcl_AppendResult(interp, "bogus syntax for plmap, see doc.",
 			 (char *) NULL );
 	return TCL_ERROR;
     }
 
-    transform = atoi(argv[2]);
-    minlong = atof( argv[3] );
-    maxlong = atof( argv[4] );
-    minlat = atof( argv[5] );
-    maxlat = atof( argv[6] );
-
-    if (transform) {
-	plmap(&mapform, argv[1], minlong, maxlong, minlat, maxlat);
+    if ( argc == 6 ) {
+        transform = 0;
+        idxname = 1;
+        transform_name = NULL;
+        minlong = atof( argv[2] );
+        maxlong = atof( argv[3] );
+        minlat = atof( argv[4] );
+        maxlat = atof( argv[5] );
     } else {
-	plmap(NULL, argv[1], minlong, maxlong, minlat, maxlat);
+        transform = 1;
+        idxname = 2;
+        minlong = atof( argv[3] );
+        maxlong = atof( argv[4] );
+        minlat = atof( argv[5] );
+        maxlat = atof( argv[6] );
+
+        tcl_interp = interp;
+        transform_name = argv[1];
+        if (strlen(transform_name) == 0) {
+           idxname = 1;
+        }
+    }
+
+    if (transform && idxname == 2) {
+	plmap(&mapform, argv[idxname], minlong, maxlong, minlat, maxlat);
+    } else {
+	/* No transformation given */
+	plmap(NULL, argv[idxname], minlong, maxlong, minlat, maxlat);
     }
 
     plflush();
-    return TCL_OK;
+    return return_code;
 }
 
 /*--------------------------------------------------------------------------*\
@@ -2862,19 +2964,38 @@ plmeridiansCmd( ClientData clientData, Tcl_Interp *interp,
     PLFLT dlong, dlat, minlong, maxlong, minlat, maxlat;
     PLINT transform;
 
-    if (argc < 8 ) {
-	Tcl_AppendResult(interp, "bogus syntax for plmap, see doc.",
+    return_code = TCL_OK;
+
+    if (argc < 7 || argc > 8) {
+	Tcl_AppendResult(interp, "bogus syntax for plmeridians, see doc.",
 			 (char *) NULL );
 	return TCL_ERROR;
     }
 
-    transform = atoi(argv[1]);
-    dlong = atof( argv[2] );
-    dlat = atof( argv[3] );
-    minlong = atof( argv[4] );
-    maxlong = atof( argv[5] );
-    minlat = atof( argv[6] );
-    maxlat = atof( argv[7] );
+    if ( argc == 7 ) {
+        transform = 0;
+        transform_name = NULL;
+        dlong = atof( argv[1] );
+        dlat = atof( argv[2] );
+        minlong = atof( argv[3] );
+        maxlong = atof( argv[4] );
+        minlat = atof( argv[5] );
+        maxlat = atof( argv[6] );
+    } else {
+        dlong = atof( argv[2] );
+        dlat = atof( argv[3] );
+        minlong = atof( argv[4] );
+        maxlong = atof( argv[5] );
+        minlat = atof( argv[6] );
+        maxlat = atof( argv[7] );
+
+        transform = 1;
+        tcl_interp = interp;
+        transform_name = argv[1];
+        if (strlen(transform_name) == 0) {
+           transform = 0;
+        }
+    }
 
     if (transform) {
 	plmeridians(&mapform, dlong, dlat, minlong, maxlong, minlat, maxlat);
@@ -2885,3 +3006,367 @@ plmeridiansCmd( ClientData clientData, Tcl_Interp *interp,
     plflush();
     return TCL_OK;
 }
+
+/*--------------------------------------------------------------------------*\
+ * plgriddataCmd
+ *
+ * Processes plgriddata Tcl command.
+\*--------------------------------------------------------------------------*/
+static int
+plgriddataCmd( ClientData clientData, Tcl_Interp *interp,
+	   int argc, const char *argv[] )
+{
+    tclMatrix *arrx, *arry, *arrz, *xcoord, *ycoord, *zvalue;
+    PLINT pts, nx, ny, alg;
+    PLFLT optalg;
+    PLFLT **z;
+
+    double value;
+    int i, j;
+
+    if (argc  != 9 ) {
+	Tcl_AppendResult( interp, "wrong # args: see documentation for ",
+			 argv[0], (char *) NULL);
+	return TCL_ERROR;
+    }
+
+    arrx = Tcl_GetMatrixPtr(interp, argv[1]);
+    arry = Tcl_GetMatrixPtr(interp, argv[2]);
+    arrz = Tcl_GetMatrixPtr(interp, argv[3]);
+
+    xcoord = Tcl_GetMatrixPtr(interp, argv[4]);
+    ycoord = Tcl_GetMatrixPtr(interp, argv[5]);
+
+    zvalue = Tcl_GetMatrixPtr(interp, argv[6]);
+
+    sscanf( argv[7], "%d", &alg);
+
+    sscanf( argv[8], "%lg", &value); optalg = (PLFLT)value;
+
+    if (arrx == NULL || arrx->dim != 1) {
+        Tcl_AppendResult(interp, argv[0], ": argument 1 should be a \
+one-dimensional matrix - ", argv[1], (char *) NULL);
+        return TCL_ERROR;
+    }
+    if (arry == NULL || arry->dim != 1) {
+        Tcl_AppendResult(interp, argv[0], ": argument 2 should be a \
+one-dimensional matrix - ", argv[2], (char *) NULL);
+        return TCL_ERROR;
+    }
+    if (arrz == NULL || arrz->dim != 1) {
+        Tcl_AppendResult(interp, argv[0], ": argument 3 should be a \
+one-dimensional matrix - ", argv[3], (char *) NULL);
+        return TCL_ERROR;
+    }
+
+    if (xcoord == NULL || xcoord->dim != 1) {
+        Tcl_AppendResult(interp, argv[0], ": argument 4 should be a \
+one-dimensional matrix - ", argv[4], (char *) NULL);
+        return TCL_ERROR;
+    }
+    if (ycoord == NULL || ycoord->dim != 1) {
+        Tcl_AppendResult(interp, argv[0], ": argument 5 should be a \
+one-dimensional matrix - ", argv[5], (char *) NULL);
+        return TCL_ERROR;
+    }
+    if (zvalue == NULL || zvalue->dim != 2) {
+        Tcl_AppendResult(interp, argv[0], ": argument 6 should be a \
+two-dimensional matrix - ", argv[6], (char *) NULL);
+        return TCL_ERROR;
+    }
+
+    pts = arrx->n[0];
+    nx  = zvalue->n[0];
+    ny  = zvalue->n[1];
+
+    /* convert zvalue to 2d-array so can use standard wrap approach
+     * from now on in this code. */
+    plAlloc2dGrid(&z, nx, ny );
+
+    /* Interpolate the data */
+    plgriddata( arrx->fdata, arry->fdata, arrz->fdata, pts,
+       xcoord->fdata, nx, ycoord->fdata, ny, z, alg, optalg );
+
+    /* Copy the result into the matrix */
+    for (i=0; i < nx; i++) {
+       for (j=0; j < ny; j++) {
+          zvalue->fdata[j+zvalue->n[1]*i] = z[i][j];
+       }
+    }
+
+    plFree2dGrid( z, nx, ny );
+    return TCL_OK;
+}
+
+/*--------------------------------------------------------------------------*\
+ * plimageCmd
+ *
+ * Processes plimage Tcl command.
+\*--------------------------------------------------------------------------*/
+static int
+plimageCmd( ClientData clientData, Tcl_Interp *interp,
+	   int argc, const char *argv[] )
+{
+    tclMatrix *zvalue;
+    PLINT nx, ny;
+    PLFLT **pidata;
+    PLFLT xmin, xmax, ymin, ymax, zmin, zmax, Dxmin, Dxmax, Dymin, Dymax;
+
+    double value;
+    int i, j;
+
+    if (argc  != 12 ) {
+	Tcl_AppendResult( interp, "wrong # args: see documentation for ",
+			 argv[0], (char *) NULL);
+	return TCL_ERROR;
+    }
+
+    zvalue = Tcl_GetMatrixPtr(interp, argv[1]);
+
+    if (zvalue == NULL || zvalue->dim != 2) {
+        Tcl_AppendResult(interp, argv[0], ": argument 1 should be a \
+two-dimensional matrix - ", argv[1], (char *) NULL);
+        return TCL_ERROR;
+    }
+
+    sscanf( argv[2],  "%lg", &value); xmin  = (PLFLT)value;
+    sscanf( argv[3],  "%lg", &value); xmax  = (PLFLT)value;
+    sscanf( argv[4],  "%lg", &value); ymin  = (PLFLT)value;
+    sscanf( argv[5],  "%lg", &value); ymax  = (PLFLT)value;
+    sscanf( argv[6],  "%lg", &value); zmin  = (PLFLT)value;
+    sscanf( argv[7],  "%lg", &value); zmax  = (PLFLT)value;
+    sscanf( argv[8],  "%lg", &value); Dxmin = (PLFLT)value;
+    sscanf( argv[9],  "%lg", &value); Dxmax = (PLFLT)value;
+    sscanf( argv[10], "%lg", &value); Dymin = (PLFLT)value;
+    sscanf( argv[11], "%lg", &value); Dymax = (PLFLT)value;
+
+    nx  = zvalue->n[0];
+    ny  = zvalue->n[1];
+
+    plAlloc2dGrid(&pidata, nx, ny);
+
+    for ( i = 0 ; i < nx ; i ++ ) {
+        for ( j = 0 ; j < ny ; j ++ ) {
+            pidata[i][j] = zvalue->fdata[j + i * ny];
+        }
+    }
+    /*
+    fprintf(stderr,"nx, ny: %d %d\n", nx, ny);
+    fprintf(stderr,"xmin, xmax: %.17g %.17g\n", xmin, xmax);
+    fprintf(stderr,"ymin, ymax: %.17g %.17g\n", ymin, ymax);
+    fprintf(stderr,"zmin, zmax: %.17g %.17g\n", zmin, zmax);
+    fprintf(stderr,"Dxmin, Dxmax: %.17g %.17g\n", Dxmin, Dxmax);
+    fprintf(stderr,"Dymin, Dymax: %.17g %.17g\n", Dymin, Dymax);
+    */
+
+    c_plimage(pidata, nx, ny, xmin, xmax, ymin, ymax, zmin, zmax,
+         Dxmin, Dxmax, Dymin, Dymax);
+
+    plFree2dGrid(pidata, nx, ny);
+
+    return TCL_OK;
+}
+
+/*--------------------------------------------------------------------------*\
+ * plimagefrCmd
+ *
+ * Processes plimagefr Tcl command.
+ *
+ * Note:
+ * Very basic! No user-defined interpolation routines
+\*--------------------------------------------------------------------------*/
+static int
+plimagefrCmd( ClientData clientData, Tcl_Interp *interp,
+	   int argc, const char *argv[] )
+{
+    tclMatrix *zvalue;
+    tclMatrix *xg;
+    tclMatrix *yg;
+    PLINT      nx, ny;
+    PLFLT    **pidata;
+    PLcGrid2   cgrid2;
+    PLFLT      xmin, xmax, ymin, ymax, zmin, zmax, valuemin, valuemax;
+
+    double value;
+    int i, j;
+
+    if (argc  != 12 && argc != 10) {
+	Tcl_AppendResult( interp, "wrong # args: see documentation for ",
+			 argv[0], (char *) NULL);
+	return TCL_ERROR;
+    }
+
+    zvalue = Tcl_GetMatrixPtr(interp, argv[1]);
+
+    if (zvalue == NULL || zvalue->dim != 2) {
+        Tcl_AppendResult(interp, argv[0], ": argument 1 should be a \
+two-dimensional matrix - ", argv[1], (char *) NULL);
+        return TCL_ERROR;
+    }
+
+    xg = NULL;
+    yg = NULL;
+    if (argc == 12) {
+        xg = Tcl_GetMatrixPtr(interp, argv[10]);
+        yg = Tcl_GetMatrixPtr(interp, argv[11]);
+
+        if (xg == NULL || xg->dim != 2) {
+           Tcl_AppendResult(interp, argv[0], ": argument 10 should be a \
+two-dimensional matrix - ", argv[10], (char *) NULL);
+           return TCL_ERROR;
+        }
+
+        if (yg == NULL || yg->dim != 2) {
+           Tcl_AppendResult(interp, argv[0], ": argument 11 should be a \
+two-dimensional matrix - ", argv[11], (char *) NULL);
+           return TCL_ERROR;
+        }
+    }
+
+    sscanf( argv[2], "%lg", &value); xmin     = (PLFLT)value;
+    sscanf( argv[3], "%lg", &value); xmax     = (PLFLT)value;
+    sscanf( argv[4], "%lg", &value); ymin     = (PLFLT)value;
+    sscanf( argv[5], "%lg", &value); ymax     = (PLFLT)value;
+    sscanf( argv[6], "%lg", &value); zmin     = (PLFLT)value;
+    sscanf( argv[7], "%lg", &value); zmax     = (PLFLT)value;
+    sscanf( argv[8], "%lg", &value); valuemin = (PLFLT)value;
+    sscanf( argv[9], "%lg", &value); valuemax = (PLFLT)value;
+
+    nx  = zvalue->n[0];
+    ny  = zvalue->n[1];
+
+    plAlloc2dGrid(&pidata, nx, ny);
+
+    for ( i = 0 ; i < nx ; i ++ ) {
+        for ( j = 0 ; j < ny ; j ++ ) {
+            pidata[i][j] = zvalue->fdata[j + i * ny];
+        }
+    }
+
+    if (xg != NULL) {
+        plAlloc2dGrid(&cgrid2.xg, nx+1, ny+1);
+        plAlloc2dGrid(&cgrid2.yg, nx+1, ny+1);
+
+        cgrid2.nx = nx+1;
+        cgrid2.ny = ny+1;
+        for ( i = 0 ; i <= nx ; i ++ ) {
+            for ( j = 0 ; j <= ny ; j ++ ) {
+                cgrid2.xg[i][j] = xg->fdata[j + i * (ny+1)];
+                cgrid2.yg[i][j] = yg->fdata[j + i * (ny+1)];
+            }
+        }
+        c_plimagefr(pidata, nx, ny, xmin, xmax, ymin, ymax, zmin, zmax,
+             valuemin, valuemax, pltr2, (void *) &cgrid2);
+    } else {
+        c_plimagefr(pidata, nx, ny, xmin, xmax, ymin, ymax, zmin, zmax,
+             valuemin, valuemax, pltr0, NULL);
+    }
+
+    plFree2dGrid(pidata, nx, ny);
+    if (xg != NULL) {
+        plFree2dGrid(cgrid2.xg, nx+1, ny+1);
+        plFree2dGrid(cgrid2.yg, nx+1, ny+1);
+    }
+
+    return TCL_OK;
+}
+
+/*--------------------------------------------------------------------------*\
+ * plstripcCmd
+ *
+ * Processes plstripc Tcl command.
+\*--------------------------------------------------------------------------*/
+static int
+plstripcCmd( ClientData clientData, Tcl_Interp *interp,
+	   int argc, const char *argv[] )
+{
+    int        i;
+    int        id;
+    const char *xspec;
+    const char *yspec;
+    const char *idName;
+    tclMatrix *colMat;
+    tclMatrix *styleMat;
+    double     value;
+    int        ivalue;
+    PLFLT      xmin, xmax, xjump, ymin, ymax, xlpos, ylpos;
+    PLBOOL     y_ascl, acc;
+    PLINT      colbox, collab;
+    PLINT      colline[4], styline[4];
+    int        nlegend;
+    const char     **legline;
+    const char *labx;
+    const char *laby;
+    const char *labtop;
+    char       idvalue[20];
+
+    if (argc  != 21) {
+	Tcl_AppendResult( interp, "wrong # args: see documentation for ",
+			 argv[0], (char *) NULL);
+	return TCL_ERROR;
+    }
+
+    colMat = Tcl_GetMatrixPtr(interp, argv[15]);
+    styleMat = Tcl_GetMatrixPtr(interp, argv[16]);
+
+    if (colMat == NULL || colMat->dim != 1 || colMat->idata == NULL) {
+        Tcl_AppendResult(interp, argv[0], ": argument 15 should be a \
+one-dimensional integer matrix - ", argv[15], (char *) NULL);
+        return TCL_ERROR;
+    }
+
+    if (styleMat == NULL || styleMat->dim != 1 || styleMat->idata == NULL) {
+        Tcl_AppendResult(interp, argv[0], ": argument 16 should be a \
+one-dimensional integer matrix - ", argv[16], (char *) NULL);
+        return TCL_ERROR;
+    }
+
+    idName = argv[1];
+    xspec  = argv[2];
+    yspec  = argv[3];
+
+    sscanf( argv[4], "%lg", &value); xmin     = (PLFLT)value;
+    sscanf( argv[5], "%lg", &value); xmax     = (PLFLT)value;
+    sscanf( argv[6], "%lg", &value); xjump    = (PLFLT)value;
+    sscanf( argv[7], "%lg", &value); ymin     = (PLFLT)value;
+    sscanf( argv[8], "%lg", &value); ymax     = (PLFLT)value;
+    sscanf( argv[9], "%lg", &value); xlpos    = (PLFLT)value;
+    sscanf( argv[10],"%lg", &value); ylpos    = (PLFLT)value;
+    sscanf( argv[11],"%d", &ivalue); y_ascl   = (PLBOOL)ivalue;
+    sscanf( argv[12],"%d", &ivalue); acc      = (PLBOOL)ivalue;
+    sscanf( argv[13],"%d", &ivalue); colbox   = ivalue;
+    sscanf( argv[14],"%d", &ivalue); collab   = ivalue;
+
+    labx   = argv[18];
+    laby   = argv[19];
+    labtop = argv[20];
+
+    for ( i = 0; i < 4; i ++ ) {
+        colline[i] = colMat->idata[i];
+        styline[i] = styleMat->idata[i];
+    }
+
+    if ( Tcl_SplitList( interp, argv[17], &nlegend, &legline ) != TCL_OK ) {
+        return TCL_ERROR;
+    }
+    if ( nlegend < 4 ) {
+        Tcl_AppendResult(interp, argv[0], ": argument 18 should be a \
+list of at least four items - ", argv[17], (char *) NULL);
+        return TCL_ERROR;
+    }
+
+    c_plstripc(&id, xspec, yspec,
+               xmin, xmax, xjump, ymin, ymax,
+               xlpos, ylpos,
+               y_ascl, acc,
+               colbox, collab,
+               colline, styline, legline,
+               labx, laby, labtop);
+
+    sprintf( idvalue, "%d", id );
+    Tcl_SetVar( interp, idName, idvalue, 0 );
+
+    Tcl_Free( (char *)legline );
+
+    return TCL_OK;
+}
