@@ -1,4 +1,4 @@
-/* $Id: tclMatrix.c 8186 2008-01-29 10:50:48Z andrewross $
+/* $Id: tclMatrix.c 9269 2009-01-07 05:19:13Z arjenmarkus $
 
     Copyright 1994, 1995
     Maurice LeBrun			mjl@dino.ph.utexas.edu
@@ -349,7 +349,7 @@ Tcl_MatrixCmd(ClientData clientData, Tcl_Interp *interp,
  *
 \*--------------------------------------------------------------------------*/
 
-tclMatrix PLDLLIMPEXP *
+tclMatrix *
 Tcl_GetMatrixPtr(Tcl_Interp *interp, const char *matName)
 {
     Tcl_HashEntry *hPtr;
@@ -642,7 +642,7 @@ MatrixCmd(ClientData clientData, Tcl_Interp *interp,
 	    Mat_float max = matPtr->fdata[0];
 	    for (i = 1; i < len; i++)
 		max = MAX(max, matPtr->fdata[i]);
-	    sprintf(tmp, "%g", max);
+	    sprintf(tmp, "%.17g", max);
 	    Tcl_AppendResult(interp, tmp, (char *) NULL);
 	    break;
 	}
@@ -678,7 +678,7 @@ MatrixCmd(ClientData clientData, Tcl_Interp *interp,
 	    Mat_float min = matPtr->fdata[0];
 	    for (i = 1; i < len; i++)
 		min = MIN(min, matPtr->fdata[i]);
-	    sprintf(tmp, "%g", min);
+	    sprintf(tmp, "%.17g", min);
 	    Tcl_AppendResult(interp, tmp, (char *) NULL);
 	    break;
 	}
@@ -891,7 +891,7 @@ MatrixGet_f(ClientData clientData, Tcl_Interp* interp, int index, char *string)
     tclMatrix *matPtr = (tclMatrix *) clientData;
     double value = matPtr->fdata[index];
 
-    sprintf(string, "%.12g", value);
+    sprintf(string, "%.17g", value);
 }
 
 static void
@@ -899,7 +899,11 @@ MatrixPut_i(ClientData clientData, Tcl_Interp* interp, int index, const char *st
 {
     tclMatrix *matPtr = (tclMatrix *) clientData;
 
-    matPtr->idata[index] = atoi(string);
+    if ((strlen(string) > 2) && (strncmp(string,"0x",2) == 0)) {
+      matPtr->idata[index] = strtoul(&string[2],NULL,16);
+    }
+    else
+      matPtr->idata[index] = atoi(string);
 }
 
 static void
