@@ -1,4 +1,4 @@
-/* $Id: tcpip.c 6950 2006-08-08 00:54:05Z airwin $
+/* $Id: tcpip.c 8353 2008-04-02 04:24:26Z arjenmarkus $
  *
  * Maurice LeBrun
  * 6-Jan-94
@@ -551,7 +551,10 @@ readError:
      * Remove the file handler and close the file.
      */
     if (iodev->type == 0) {
+/* Exclude UNIX-only feature */
+#if !defined(MAC_TCL) && !defined(__WIN32__) && !defined(__CYGWIN__)
 	Tk_DeleteFileHandler(iodev->fd);
+#endif
 	close(iodev->fd);
     }
     pl_FreeReadBuffer(iodev->fd);
