@@ -1,4 +1,4 @@
-/* $Id: tkMain.c 8198 2008-01-30 18:58:16Z andrewross $
+/* $Id: tkMain.c 8875 2008-10-10 20:27:47Z airwin $
  *
  * Modified version of tkMain.c, from Tk 3.6.
  * Maurice LeBrun
@@ -62,7 +62,7 @@
  */
 
 #include "plplotP.h"
-
+#include "pltkd.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <tcl.h>
@@ -374,7 +374,10 @@ pltkMain(int argc, const char **argv, char *RcFileName,
 	    }
 	    Tcl_DStringFree(&buffer);
 	}
+/* Exclude UNIX-only feature */
+#if !defined(MAC_TCL) && !defined(__WIN32__) && !defined(__CYGWIN__)
 	Tk_CreateFileHandler(0, TK_READABLE, StdinProc, (ClientData) 0);
+#endif
 	if (tty) {
 	    Prompt(interp, 0);
 	}
@@ -447,7 +450,9 @@ StdinProc(clientData, mask)
 		Tcl_Eval(interp, "exit");
 		exit(1);
 	    } else {
+#if !defined(MAC_TCL) && !defined(__WIN32__) && !defined(__CYGWIN__)
 		Tk_DeleteFileHandler(0);
+#endif
 	    }
 	    return;
 	} else {
@@ -474,10 +479,13 @@ StdinProc(clientData, mask)
      * finished.  Among other things, this will trash the text of the
      * command being evaluated.
      */
-
+#if !defined(MAC_TCL) && !defined(__WIN32__) && !defined(__CYGWIN__)
     Tk_CreateFileHandler(0, 0, StdinProc, (ClientData) 0);
+#endif
     code = Tcl_RecordAndEval(interp, cmd, 0);
+#if !defined(MAC_TCL) && !defined(__WIN32__) && !defined(__CYGWIN__)
     Tk_CreateFileHandler(0, TK_READABLE, StdinProc, (ClientData) 0);
+#endif
     Tcl_DStringFree(&command);
     if (*interp->result != 0) {
 	if ((code != TCL_OK) || (tty)) {
