@@ -1,4 +1,4 @@
-/* $Id: wxPLplotwindow.h 8217 2008-02-06 15:20:30Z smekal $
+/* $Id: wxPLplotwindow.h 8870 2008-10-10 06:33:54Z smekal $
 
    Copyright (C) 2005  Werner Smekal
 
@@ -31,7 +31,7 @@
  *  provide an own plot API. You have to get a pointer to wxPLplotstream via the 
  *  GetStream() method to gain access to the PLplot API.
  */
-class PLDLLIMPEXP wxPLplotwindow : public wxWindow
+class PLDLLIMPEXP_WX wxPLplotwindow : public wxWindow
 {
 public:
 	wxPLplotwindow( wxWindow* parent, wxWindowID id=-1, const wxPoint& pos = wxDefaultPosition,
@@ -44,14 +44,17 @@ public:
 	wxPLplotstream* GetStream()  { return m_stream; }  //!< Get pointer to wxPLplotstream of this widget.
 	
 protected:
-  virtual void OnPaint( wxPaintEvent& event );   //!< Paint event.
-	virtual void OnErase( wxEraseEvent &WXUNUSED(event) );   //!< Erase event.
+  virtual void OnPaint( wxPaintEvent& event );           //!< Paint event
+	virtual void OnErase( wxEraseEvent &WXUNUSED(event) ); //!< Erase event
+  virtual void OnSize( wxSizeEvent & WXUNUSED(event) );  //!< Size event
 
 private:
   // variables regarding double buffering
   wxMemoryDC* MemPlotDC;      //!< Pointer to wxMemoryDC, used for double buffering
-  int MemPlotDC_width;        //!< Saved width of MemoryDC, to find out if size changed.
-  int MemPlotDC_height;       //!< Saved height of MemoryDC, to find out if size changed.
+  int m_width;                //!< Saved width of plot, to find out if size changed.
+  int m_height;               //!< Saved height of plot, to find out if size changed.
+  int bitmapWidth;                //!< Width of bitmap, only changed if plot gets bigger
+  int bitmapHeight;               //!< Height of bitmap, only changed if plot gets bigger
   wxBitmap* MemPlotDCBitmap;  //!< Pointer to bitmap, used for double buffering.
 
 protected:
