@@ -1,4 +1,4 @@
-/* $Id: dg300.c 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: dg300.c 8882 2008-10-11 06:15:24Z airwin $
 
 	PLplot dg300 device driver.
 */
@@ -10,7 +10,7 @@
 #include "drivers.h"
 
 /* Device info */
-const char* plD_DEVICE_INFO_dg300 = "dg300:DG300 Terminal:0:dg300:25:dg300";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_dg300 = "dg300:DG300 Terminal:0:dg300:25:dg300";
 
 void plD_dispatch_init_dg	( PLDispatchTable *pdt );
 
