@@ -1,4 +1,4 @@
-/* $Id: gd.c 8156 2008-01-22 13:57:53Z andrewross $
+/* $Id: gd.c 9207 2008-12-19 18:09:25Z airwin $
 
          PNG, GIF, and JPEG device driver based on libgd
 
@@ -132,7 +132,7 @@
  *  and finally one of each.
  */
 
-const char* plD_DEVICE_INFO_gd =
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_gd =
 #if defined(PLD_png)
   "png:PNG file:0:gd:39:png\n"
 #endif
@@ -193,11 +193,6 @@ static void plD_set_pixel_gd (PLStream *pls, short x, short y, PLINT colour);
 static void init_freetype_lv1 (PLStream *pls);
 static void init_freetype_lv2 (PLStream *pls);
 
-extern void plD_FreeType_init(PLStream *pls);
-extern void plD_render_freetype_text (PLStream *pls, EscText *args);
-extern void plD_FreeType_Destroy(PLStream *pls);
-extern void pl_set_extended_cmap0(PLStream *pls, int ncol0_width, int ncol0_org);
-
 #endif
 
 /* top level declarations */
@@ -235,10 +230,12 @@ static int NCOLOURS=gdMaxColors;
 #define gdImagePalettePixel(  im, x, y )   (im)->pixels[(y)][(x)]
 #endif
 
+#if GD2_VERS >= 2
 int plToGdAlpha( PLFLT a ) {
   int tmp = (int)((1.0-a)*gdAlphaMax);
   return tmp;
 }
+#endif
 
 /* Struct to hold device-specific info. */
 
@@ -252,7 +249,7 @@ typedef struct {
         int totcol;                             /* Total number of colours      */
         int ncol1;                              /* Actual size of ncol1 we got  */
 
-        int scale;                              /* scaling factor to "blow up" to */
+        PLFLT scale;                            /* scaling factor to "blow up" to */
                                                 /* the "virtual" page in removing hidden lines*/
 
         int optimise;                           /* Flag used for 4bit pngs */
@@ -405,12 +402,6 @@ plD_init_png_Dev(PLStream *pls)
 
     dev->colour=1;  /* Set a fall back pen colour in case user doesn't */
 
-/*
- *  Set the compression/quality level for JPEG files
- *  The higher the value, the bigger/better the image is
- */
-    if ( (pls->dev_compression<=0)||(pls->dev_compression>99) )
-       pls->dev_compression=90;
 
 /* Check for and set up driver options */
 
@@ -510,15 +501,15 @@ void plD_init_png(PLStream *pls)
 
      if (dev->pngx>dev->pngy)    /* Work out the scaling factor for the  */
         {                        /* "virtual" (oversized) page           */
-        dev->scale=PIXELS_X/dev->pngx;
+        dev->scale=(PLFLT)(PIXELS_X-1)/(PLFLT)dev->pngx;
         }
      else
         {
-        dev->scale=PIXELS_Y/dev->pngy;
+        dev->scale=(PLFLT)PIXELS_Y/(PLFLT)dev->pngy;
         }
 #else
 
-     dev->scale=1;
+     dev->scale=1.;
 
 #endif
 
@@ -666,15 +657,15 @@ void plD_init_gif(PLStream *pls)
 
      if (dev->pngx>dev->pngy)    /* Work out the scaling factor for the  */
         {                        /* "virtual" (oversized) page           */
-        dev->scale=PIXELS_X/dev->pngx;
+        dev->scale=(PLFLT)(PIXELS_X-1)/(PLFLT)dev->pngx;
         }
      else
         {
-        dev->scale=PIXELS_Y/dev->pngy;
+        dev->scale=(PLFLT)PIXELS_Y/(PLFLT)dev->pngy;
         }
 #else
 
-     dev->scale=1;
+     dev->scale=1.;
 
 #endif
 
@@ -1169,8 +1160,6 @@ void plD_tidy_png(PLStream *pls)
 #ifdef HAVE_FREETYPE
    if (pls->dev_text)
      {
-	FT_Data *FT=(FT_Data *)pls->FT;
-	plscmap0n(FT->ncol0_org);
 	plD_FreeType_Destroy(pls);
      }
 #endif
@@ -1314,6 +1303,7 @@ void plD_eop_png(PLStream *pls)
 {
     png_Dev *dev=(png_Dev *)pls->dev;
     int im_size=0;
+    int png_compression;
     void *im_ptr=NULL;
 
     if (pls->family || pls->page == 1) {
@@ -1340,7 +1330,20 @@ void plD_eop_png(PLStream *pls)
           lib a crash occurs - this fix works also in Linux */
        /* gdImagePng(dev->im_out, pls->OutFile); */
        #if GD2_VERS >= 2
-         im_ptr = gdImagePngPtrEx (dev->im_out, &im_size, pls->dev_compression >9 ? (pls->dev_compression/10) : pls->dev_compression);
+ 
+       /*Set the compression/quality level for PNG files.
+   pls->dev_compression values of 1-9 translate to the zlib compression values 1-9
+   pls->dev_compression values 10 <= compression <= 99 are divided by 10 to get the zlib 
+   compression value. Values <=0 or greater than 99 are set to 90 which
+   translates to a zlib compression value of 9, the highest quality
+   of compression or smallest file size or largest computer time required
+   to achieve the compression.  Smaller zlib compression values correspond
+   to lower qualities of compression (larger file size), but lower 
+   computer times as well. */
+
+         png_compression = ((pls->dev_compression<=0)||(pls->dev_compression>99)) ? 90 : pls->dev_compression;
+         png_compression = (png_compression > 9) ? (png_compression/10) : png_compression;
+         im_ptr = gdImagePngPtrEx (dev->im_out, &im_size, png_compression);
        #else
          im_ptr = gdImagePngPtr(dev->im_out, &im_size);
        #endif
