@@ -1,4 +1,4 @@
-/* $Id: gnome.c 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: gnome.c 8882 2008-10-11 06:15:24Z airwin $
 
         PLplot GnomeCanvas device driver.
 
@@ -39,7 +39,7 @@
 #include <unistd.h>
 
 /* Device info */
-const char* plD_DEVICE_INFO_gnome = "gnome:Gnome Canvas:1:gnome:6:gnome";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_gnome = "gnome:Gnome Canvas:1:gnome:6:gnome";
 
 /*#undef DEBUG*/
 #define DEBUG
