@@ -1,4 +1,4 @@
-/* $Id: hpgl.c 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: hpgl.c 8882 2008-10-11 06:15:24Z airwin $
  *
  *  File:	hpgl.c
  *
@@ -37,7 +37,7 @@
 #include "drivers.h"
 
 /* Device info */
-const char* plD_DEVICE_INFO_hpgl =
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_hpgl =
 #if defined(PLD_hp7470)
   "hp7470:HP 7470 Plotter File (HPGL Cartridge, Small Plotter):0:hpgl:34:hp7470\n"
 #endif
