@@ -1,5 +1,5 @@
 /*
-  $Id: mem.c 8033 2007-11-23 15:28:09Z andrewross $
+  $Id: mem.c 8882 2008-10-11 06:15:24Z airwin $
 
   PLplot MEM (in user-supplied memory) device driver.
   The idea here is that the user will specify the Y by X by RGB
@@ -21,7 +21,7 @@
 #include "drivers.h"
 
 /* Device info */
-const char* plD_DEVICE_INFO_mem = "mem:User-supplied memory device:-1:mem:46:mem";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_mem = "mem:User-supplied memory device:-1:mem:46:mem";
 
 void plD_dispatch_init_mem	( PLDispatchTable *pdt );
 
