@@ -1,4 +1,4 @@
-/* $Id: ntk.c 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: ntk.c 8882 2008-10-11 06:15:24Z airwin $
 
    Experimental tk driver using a plain "wish"
 
@@ -34,7 +34,7 @@
 #include <tk.h>
 
 /* Device info */
-const char* plD_DEVICE_INFO_ntk = "ntk:New tk driver:1:ntk:43:ntk";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_ntk = "ntk:New tk driver:1:ntk:43:ntk";
 
 
 void plD_dispatch_init_ntk	( PLDispatchTable *pdt );
