@@ -1,4 +1,4 @@
-/* $Id: ps.c 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: ps.c 9074 2008-12-10 10:08:05Z andrewross $
 
 	PLplot PostScript device driver.
 
@@ -49,7 +49,7 @@
 
 /* Device info */
 
-const char* plD_DEVICE_INFO_ps = 
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_ps = 
   "ps:PostScript File (monochrome):0:ps:29:psm\n"
   "psc:PostScript File (color):0:ps:30:psc";
 
@@ -156,8 +156,18 @@ ps_init(PLStream *pls)
 {
     PSDev *dev;
 
-    PLFLT pxlx = YPSSIZE/LPAGE_X;
-    PLFLT pxly = XPSSIZE/LPAGE_Y;
+    PLFLT pxlx, pxly;
+
+    /* Set default values - 7.5 x 10 [inches] (72 points = 1 inch) */
+    if (pls->xlength <= 0 || pls->ylength <=0) {
+      pls->xlength = 540;
+      pls->ylength = 720;
+    }
+    if (pls->xdpi <= 0) pls->xdpi = 72.;
+    if (pls->ydpi <= 0) pls->ydpi = 72.;
+
+    pxlx = YPSSIZE/LPAGE_X;
+    pxly = XPSSIZE/LPAGE_Y;
 
     if (text) 
      {
@@ -340,7 +350,11 @@ ps_init(PLStream *pls)
     fprintf(OF, "/A {0.5 0 360 arc} def\n");
     fprintf(OF, "/S {stroke} def\n");
     fprintf(OF, "/Z {stroke newpath} def\n");
-    fprintf(OF, "/F {fill} def\n");
+    /* Modify to use fill and stroke for better output with 
+     * anti-aliasing */
+    /*fprintf(OF, "/F {fill} def\n");*/
+    fprintf(OF, "/F {closepath gsave fill grestore stroke} def ");
+    fprintf(OF, "/N {newpath} def");
     fprintf(OF, "/C {setrgbcolor} def\n");
     fprintf(OF, "/G {setgray} def\n");
     fprintf(OF, "/W {setlinewidth} def\n");
@@ -643,7 +657,7 @@ fill_polygon(PLStream *pls)
 /* First time through start with a x y moveto */
 
 	if (n == 0) {
-	    sprintf(outbuf, "%d %d M", x, y);
+	    sprintf(outbuf, "N %d %d M", x, y);
 	    dev->llx = MIN(dev->llx, x);
 	    dev->lly = MIN(dev->lly, y);
 	    dev->urx = MAX(dev->urx, x);
