@@ -1,4 +1,4 @@
-/* $Id: psttf.cc 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: psttf.cc 9074 2008-12-10 10:08:05Z andrewross $
 
 	PLplot PostScript device driver using LASi to provide fonts
 	based on original ps.c PostScript driver
@@ -56,7 +56,7 @@ using namespace std;
 
 /* Device info */
 
-const char* plD_DEVICE_INFO_psttf = 
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_psttf = 
   "psttf:PostScript File (monochrome):0:psttf:55:psttfm\n"
   "psttfc:PostScript File (color):0:psttf:56:psttfc";
 
@@ -82,11 +82,11 @@ static int hrshsym = 0;
 #define N_Pango_Lookup 5
 
 const char * DefaultFamilyLookup[N_Pango_Lookup] = {
-  "Arial,Bitstream-Vera-Sans,sans",
-  "Times-Roman,Bitstream-Vera-Serif,serif",
-  "Courier,Bitstream-Vera-Sans-Mono,monospace",
-  "Arial,Bitstream-Vera-Sans,sans,serif",
-  "Arial,Bitstream-Vera-Sans,sans,serif"
+  "sans",
+  "serif",
+  "monospace",
+  "sans,serif",
+  "sans,serif"
 };
 
 const char * EnvFamilyLookup[N_Pango_Lookup] = {
@@ -194,9 +194,19 @@ ps_init(PLStream *pls)
     char *a;
     PSDev *dev;
     PostscriptDocument *doc; 
+    PLFLT pxlx, pxly;
 
-    PLFLT pxlx = YPSSIZE/LPAGE_X;
-    PLFLT pxly = XPSSIZE/LPAGE_Y;
+    /* Set default values - 7.5 x 10 [inches] (72 points = 1 inch) */
+    if (pls->xlength <= 0 || pls->ylength <=0) {
+      pls->xlength = 540;
+      pls->ylength = 720;
+    }
+    if (pls->xdpi <= 0) pls->xdpi = 72.;
+    if (pls->ydpi <= 0) pls->ydpi = 72.;
+
+
+    pxlx = YPSSIZE/LPAGE_X;
+    pxly = XPSSIZE/LPAGE_Y;
 
     if (text) 
      {
@@ -408,7 +418,8 @@ writeHeader(PLStream *pls) {
     doc->osHeader() << "/A {0.5 0 360 arc} def\n";
     doc->osHeader() << "/S {stroke} def\n";
     doc->osHeader() << "/Z {stroke newpath} def\n";
-    doc->osHeader() << "/F {fill} def\n";
+    doc->osHeader() << "/F {closepath gsave fill grestore stroke} def\n";
+    doc->osHeader() << "/N {newpath} def\n";
     doc->osHeader() << "/C {setrgbcolor} def\n";
     doc->osHeader() << "/G {setgray} def\n";
     doc->osHeader() << "/W {setlinewidth} def\n";
@@ -723,7 +734,7 @@ fill_polygon(PLStream *pls)
 /* First time through start with a x y moveto */
 
 	if (n == 0) {
-	    sprintf(outbuf, "%d %d M", x, y);
+	    sprintf(outbuf, "N %d %d M", x, y);
 	    dev->llx = MIN(dev->llx, x);
 	    dev->lly = MIN(dev->lly, y);
 	    dev->urx = MAX(dev->urx, x);
