@@ -1,4 +1,4 @@
-/* $Id: tek.c 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: tek.c 8882 2008-10-11 06:15:24Z airwin $
 
 	PLplot tektronix device & emulators driver.
 */
@@ -23,7 +23,7 @@
 
 /* Device info */
 
-const char* plD_DEVICE_INFO_tek = 
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_tek = 
 #if defined(PLD_conex)
   "conex:Conex vt320/tek emulator:1:tek:24:conex\n"
 #endif
