@@ -1,4 +1,4 @@
-/* $Id: tk.c 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: tk.c 8882 2008-10-11 06:15:24Z airwin $
  *
  *	PLplot Tcl/Tk and Tcl-DP device drivers.
  *	Should be broken up somewhat better to allow use of DP w/o X.
@@ -63,7 +63,7 @@
 #endif
 
 /* Device info */
-const char* plD_DEVICE_INFO_tk = "tk:Tcl/TK Window:1:tk:7:tk";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_tk = "tk:Tcl/TK Window:1:tk:7:tk";
 
 
 /* Number of instructions to skip between updates */
