@@ -1,4 +1,4 @@
-/* $Id: tkwin.c 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: tkwin.c 8882 2008-10-11 06:15:24Z airwin $
  *
  * PLplot Tk device driver.
  *
@@ -80,7 +80,7 @@
 #endif
 
 /* Device info */
-const char* plD_DEVICE_INFO_tkwin = "tkwin:New tk driver:1:tkwin:45:tkwin";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_tkwin = "tkwin:New tk driver:1:tkwin:45:tkwin";
 
 
 void *	ckcalloc(size_t nmemb, size_t size);
