@@ -1,4 +1,4 @@
-/* $Id: wingcc.c 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: wingcc.c 8882 2008-10-11 06:15:24Z airwin $
 
 	PLplot WIN32 under GCC device driver.
 
@@ -62,7 +62,7 @@
 
 /* Device info */
 
-const char* plD_DEVICE_INFO_wingcc = "wingcc:Win32 (GCC):1:wingcc:9:wingcc";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_wingcc = "wingcc:Win32 (GCC):1:wingcc:9:wingcc";
 
 /* Struct to hold device-specific info. */
 
@@ -133,10 +133,6 @@ static void plD_set_pixelV_wingcc (PLStream *pls, short x, short y,PLINT colour)
 static void init_freetype_lv1 (PLStream *pls);
 static void init_freetype_lv2 (PLStream *pls);
 
-extern void plD_FreeType_init(PLStream *pls);
-extern void plD_render_freetype_text (PLStream *pls, EscText *args);
-extern void plD_FreeType_Destroy(PLStream *pls);
-extern void pl_set_extended_cmap0(PLStream *pls, int ncol0_width, int ncol0_org);
 #endif
 
 
@@ -620,7 +616,7 @@ plD_state_wingcc(pls, PLSTATE_COLOR0);
 
     if (dev->width>dev->height)           /* Work out the scaling factor for the  */
       {                                   /* "virtual" (oversized) page           */
-        dev->scale=(PLFLT)PIXELS_X/dev->width;
+        dev->scale=(PLFLT)(PIXELS_X-1)/dev->width;
       }
     else
       {
@@ -660,7 +656,12 @@ plD_line_wingcc(PLStream *pls, short x1a, short y1a, short x2a, short y2a)
   points[1].y=dev->height - (y2a/dev->scale);
 
   dev->oldobject = SelectObject (dev->hdc, dev->pen);
-  Polyline(dev->hdc, points,2);
+
+  if ( points[0].x != points[1].x || points[0].y != points[1].y ) {
+      Polyline(dev->hdc, points,2);
+  } else {
+      SetPixel(dev->hdc, points[0].x, points[0].y, dev->colour);
+  }
   SelectObject (dev->hdc, dev->oldobject);
 
 }
@@ -1009,7 +1010,7 @@ static void Resize( PLStream *pls )
               dev->height=dev->rect.bottom;
               if (dev->width>dev->height)           /* Work out the scaling factor for the  */
                 {                                   /* "virtual" (oversized) page           */
-                  dev->scale=(PLFLT)PIXELS_X/dev->width;
+                  dev->scale=(PLFLT)(PIXELS_X-1)/dev->width;
                 }
               else
                 {
@@ -1122,7 +1123,7 @@ static void plD_pixelV_wingcc (PLStream *pls, short x, short y)
 /*----------------------------------------------------------------------*\
  *  void plD_set_pixelV_wingcc (PLStream *pls, short x, short y,PLINT colour)
  *
- *  callback function, of type "plD_set_pixel_fp", which specifies how a 
+ *  callback function, of type "plD_set_pixel_fp", which specifies how a
  *  single pixel is set in the s[ecified colour. This colour
  *  by-passes plplot's internal table, and directly 'hits the hardware'.
 \*----------------------------------------------------------------------*/
@@ -1299,7 +1300,7 @@ static void UpdatePageMetrics ( PLStream *pls, char flag )
 
   if (dev->width>dev->height)           /* Work out the scaling factor for the  */
     {                                   /* "virtual" (oversized) page           */
-      dev->scale=(PLFLT)PIXELS_X/dev->width;
+      dev->scale=(PLFLT)(PIXELS_X-1)/dev->width;
     }
   else
     {
