@@ -1,4 +1,4 @@
-/* $Id: xwin.c 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: xwin.c 8882 2008-10-11 06:15:24Z airwin $
 
 	PLplot X-windows device driver.
 
@@ -45,7 +45,7 @@ static int already = 0;
 #endif
 
 /* Device info */
-const char* plD_DEVICE_INFO_xwin = "xwin:X-Window (Xlib):1:xwin:5:xw";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_xwin = "xwin:X-Window (Xlib):1:xwin:5:xw";
 
 static int synchronize = 0;	/* change to 1 for X synchronized operation */
                                 /* Use "-drvopt sync" cmd line option to set. */
