@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x01.cc 8033 2007-11-23 15:28:09Z andrewross $
+// $Id: x01.cc 9130 2008-12-16 12:23:21Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -125,8 +125,6 @@ x01::x01( int argc, const char ** argv ) {
 
   pls = new plstream();
 
-  pls->ssub(2, 2);
-
   // Parse and process command line arguments.
   pls->MergeOpts(options, "x01c options", notes);
   pls->parseopts( &argc, argv, PL_PARSE_FULL );
@@ -138,7 +136,7 @@ x01::x01( int argc, const char ** argv ) {
 
 
   // Initialize PLplot.
-  pls->init();
+  pls->star(2,2);
 
   // Select the multi-stroke font.
   pls->fontld( 1 );
@@ -223,7 +221,6 @@ x01::x01( int argc, const char ** argv ) {
 void x01::plot1( int do_test )
 {
   int i;
-  bool st;
   PLFLT xmin, xmax, ymin, ymax;
   PLFLT *x = new PLFLT[60];
   PLFLT *y = new PLFLT[60];
@@ -270,8 +267,9 @@ void x01::plot1( int do_test )
 /* it does not work in double buffering mode, however */
 
   if (do_test && test_xor) {
-#ifdef HAVE_USLEEP
-    pls->xormod(true, &st); /* enter xor mode */
+#ifdef PL_HAVE_USLEEP
+  bool st;
+  pls->xormod(true, &st); /* enter xor mode */
     if (st) {
       for (i=0; i<60; i++) {
 	pls->poin(1, x+i, y+i,9);      /* draw a point */
