@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x14.cc 8033 2007-11-23 15:28:09Z andrewross $
+// $Id: x14.cc 9283 2009-01-08 20:46:17Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -93,6 +93,9 @@ x14::x14( int argc, const char ** argv ) {
   // The geometry strings MUST be in writable memory
 
   char driver[80];
+
+  PLINT fam, num, bmax;
+
   const char geometry_master[] = "500x410+100+200";
   const char geometry_slave[]  = "500x410+650+200";
 
@@ -104,14 +107,15 @@ x14::x14( int argc, const char ** argv ) {
   pls1->parseopts( &argc, argv, PL_PARSE_FULL );
 
   pls1->gdev(driver);
+  pls1->gfam(fam,num,bmax);
 
   cout << "Demo of multiple output streams via the " <<
     driver << " driver." << endl;
-  cout << "Running with the second stream as slave.\n" << endl;
+  cout << "Running with the second stream as slave to the first.\n" << endl;
 
   // Set up first stream
 
-  pls1->SetOpt("geometry", geometry_master);
+  pls1->setopt("geometry", geometry_master);
 
   pls1->sdev(driver);
   pls1->ssub(2, 2);
@@ -122,9 +126,13 @@ x14::x14( int argc, const char ** argv ) {
   pls2 = new plstream();
   // Turn off pause to make this a slave (must follow master)
 
-  pls2->SetOpt("geometry", geometry_slave);
+  pls2->setopt("geometry", geometry_slave);
   pls2->spause(false);
   pls2->sdev(driver);
+  pls2->sfam(fam,num,bmax);
+  // Currently number of digits in format number can only be
+  // set via the command line option
+  pls2->setopt("fflen","2");
   pls2->init();
 
   // Set up the data & plot
