@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x15.cc 8033 2007-11-23 15:28:09Z andrewross $
+// $Id: x15.cc 9130 2008-12-16 12:23:21Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -38,6 +38,7 @@ public:
   x15(int, const char **);
   void plot1( PLFLT **, PLFLT, PLFLT);
   void plot2( PLFLT **, PLFLT, PLFLT);
+  void plot3();
 
 private:
   // Class data
@@ -104,6 +105,7 @@ x15::x15( int argc, const char ** argv ) {
 
   plot1( z, zmin, zmax );
   plot2( z, zmin, zmax );
+  plot3();
 
   //pls->end();
 
@@ -159,6 +161,14 @@ void x15::plot2(PLFLT **z, PLFLT zmin, PLFLT zmax)
   int sh_cmap = 0, sh_width;
   int min_color = 0, min_width = 0, max_color = 0, max_width = 0;
   int i;
+  static PLINT nlin[10] = {1, 1, 1, 1, 1, 2, 2, 2, 2, 2};
+  static PLINT inc[10][2] = { {450, 0}, {-450, 0}, {0, 0}, {900, 0}, 
+			      {300, 0}, {450,-450}, {0, 900}, {0, 450}, 
+			      {450, -450}, {0, 900} };
+  static PLINT del[10][2] = { {2000, 2000}, {2000, 2000}, {2000, 2000}, 
+			      {2000, 2000}, {2000, 2000}, {2000, 2000}, 
+			      {2000, 2000}, {2000, 2000}, {4000, 4000}, 
+			      {4000, 2000} };
   sh_width = 2;
 
   pls->adv(0);
@@ -171,7 +181,7 @@ void x15::plot2(PLFLT **z, PLFLT zmin, PLFLT zmax)
     shade_min = zmin + (zmax - zmin) * i / 10.0;
     shade_max = zmin + (zmax - zmin) * (i +1) / 10.0;
     sh_color = i+6;
-    pls->psty((i + 2) % 8 + 1);
+    pls->pat(nlin[i],inc[i],del[i]);
 
     pls->shade( z, XPTS, YPTS, NULL, -1., 1., -1., 1.,
 		 shade_min, shade_max,
@@ -186,6 +196,41 @@ void x15::plot2(PLFLT **z, PLFLT zmin, PLFLT zmax)
   pls->lab("distance", "altitude", "Bogon flux");
 }
 
+// Illustrates shaded regions in 3d, using a different fill pattern for 
+// each region.  
+
+void x15::plot3()
+{
+    static PLFLT xx[2][5] = { {-1.0, 1.0, 1.0, -1.0, -1.0}, 
+			      {-1.0, 1.0, 1.0, -1.0, -1.0} };
+    static PLFLT yy[2][5] = { {1.0, 1.0, 0.0, 0.0, 1.0}, 
+			      {-1.0, -1.0, 0.0, 0.0, -1.0} };
+    static PLFLT zz[2][5] = { {0.0, 0.0, 1.0, 1.0, 0.0}, 
+			      {0.0, 0.0, 1.0, 1.0, 0.0} };
+
+    pls->adv(0);
+    pls->vpor(0.1, 0.9, 0.1, 0.9);
+    pls->wind(-1.0, 1.0, -1.0, 1.0);
+    pls->w3d(1., 1., 1., -1.0, 1.0, -1.0, 1.0, 0.0, 1.5, 30, -40);
+
+/* Plot using identity transform */
+    
+    pls->col0(1);
+    pls->box3("bntu", "X", 0.0, 0, "bntu", "Y", 0.0, 0, "bcdfntu", "Z", 0.5, 0);
+    pls->col0(2);
+    pls->lab("","","3-d polygon filling");
+
+    pls->col0(3);
+    pls->psty(1);
+    pls->line3(5, xx[0], yy[0], zz[0]);
+    pls->fill3(4, xx[0], yy[0], zz[0]);
+    pls->psty(2);
+    pls->line3(5, xx[1], yy[1], zz[1]);
+    pls->fill3(4, xx[1], yy[1], zz[1]);
+
+}
+
+
 int main( int argc, const char ** argv ) {
   x15 *x = new x15( argc, argv );
 
