@@ -1,4 +1,4 @@
-// $Id: x29.cc 8168 2008-01-25 09:44:50Z andrewross $
+// $Id: x29.cc 9130 2008-12-16 12:23:21Z andrewross $
 //
 //       Sample plots using date / time formatting for axes
 //
@@ -37,6 +37,7 @@ private:
   plstream *pls;
 
   PLFLT x[365], y[365];
+  PLFLT xerr1[365], xerr2[365], yerr1[365], yerr2[365];
 
   // Function prototypes  
   void plot1();
@@ -74,6 +75,8 @@ x29::x29(int argc, const char *argv[])
   // Initialize plplot 
   pls->init();
 
+  pls->sesc('@');
+
   plot1();
 
   plot2();
@@ -91,7 +94,7 @@ x29::plot1()
   PLFLT xmin, xmax, ymin, ymax;
 
   // Data points every 10 minutes for 1 day
-  npts = 145;
+  npts = 73;
 
   xmin = 0;
   xmax = 60.0*60.0*24.0;    // Number of seconds in a day
@@ -101,10 +104,21 @@ x29::plot1()
   for (i=0;i<npts;i++) {
     x[i] = xmax*((PLFLT) i/(PLFLT)npts);
     y[i] = 15.0 - 5.0*cos( 2*M_PI*((PLFLT) i / (PLFLT) npts));
+    // Set x error bars to +/- 5 minute
+    xerr1[i] = x[i]-60*5;
+    xerr2[i] = x[i]+60*5;
+    // Set y error bars to +/- 0.1 deg C
+    yerr1[i] = y[i]-0.1;
+    yerr2[i] = y[i]+0.1;
   }
   
   pls->adv(0);
 
+  // Rescale major ticks marks by 0.5
+  pls->smaj(0.0,0.5);
+  // Rescale minor ticks and error bar marks by 0.5
+  pls->smin(0.0,0.5);
+
   pls->vsta();
   pls->wind(xmin, xmax, ymin, ymax);
 
@@ -115,11 +129,20 @@ x29::plot1()
   pls->box("bcnstd", 3.0*60*60, 3, "bcnstv", 1, 5);
 
   pls->col0(3);
-  pls->lab("Time (hours:mins)", "Temperature (degC)", "#frPLplot Example 29 - Daily temperature");
+  pls->lab("Time (hours:mins)", "Temperature (degC)", "@frPLplot Example 29 - Daily temperature");
   
   pls->col0(4);
 
   pls->line(npts, x, y);
+  pls->col0(2);
+  pls->errx(npts, xerr1, xerr2, y);
+  pls->col0(3);
+  pls->erry(npts, x, yerr1, yerr2);
+
+  /* Rescale major / minor tick marks back to default */
+  pls->smin(0.0,1.0);
+  pls->smaj(0.0,1.0);
+
 }
 
 // Plot the number of hours of daylight as a function of day for a year 
@@ -155,16 +178,18 @@ x29::plot2()
   pls->col0(1);
   // Set time format to be abbreviated month name followed by day of month 
   pls->timefmt("%b %d");
+  pls->prec(1,1);
   pls->env(xmin, xmax, ymin, ymax, 0, 40);
 
 
   pls->col0(3);
-  pls->lab("Date", "Hours of daylight", "#frPLplot Example 29 - Hours of daylight at 51.5N");
+  pls->lab("Date", "Hours of daylight", "@frPLplot Example 29 - Hours of daylight at 51.5N");
   
   pls->col0(4);
 
   pls->line(npts, x, y);
-  
+
+  pls->prec(0,0);
 }
 
 void
@@ -172,30 +197,41 @@ x29::plot3()
 {
   int i, npts;
   PLFLT xmin, xmax, ymin, ymax;
-  time_t tstart, t1, t2;
-  double toff;
+  PLFLT tstart;
+  char *tz;
 
   struct tm tm;
 
-  // Warning: mktime is in local time so we need to calculate 
-  // offset to get UTC. C time handling is quirky 
-  t1 = 0;
-  tm = *gmtime(&t1);
-  t2 = mktime(&tm);
-  toff = difftime(t1,t2);
-
-  tm.tm_year = 105; // Years since 1900 
+  // Calculate seconds since the Unix epoch for 2005-12-01 UTC.
+#if defined(WIN32)
+  // Adopt the known result for POSIX-compliant systems.
+  tstart = (PLFLT) 1133395200;
+#else
+  tm.tm_year = 105; // Years since 1900 = 2005
   tm.tm_mon = 11;   // 0 == January, 11 = December 
   tm.tm_mday = 1;   // 1 = 1st of month 
   tm.tm_hour = 0;
   tm.tm_min = 0;
   tm.tm_sec = 0;
 
-  tstart = mktime(&tm);
+  // Use POSIX-compliant equivalent of timegm GNU extension.
+  tz = getenv("TZ");
+  setenv("TZ", "", 1);
+  tzset();
+  // tstart is a time_t value (cast to PLFLT) which represents the number
+  // of seconds elapsed since 00:00:00 on January 1, 1970, Coordinated 
+  // Universal Time (UTC) on  2005-12-01 (UTC).
+  tstart = (PLFLT) mktime(&tm);
+  if (tz)
+    setenv("TZ", tz, 1);
+  else
+    unsetenv("TZ");
+  tzset();
+#endif
 
   npts = 62;
 
-  xmin = (PLFLT) tstart + toff;
+  xmin = tstart;
   xmax = xmin + npts*60.0*60.0*24.0;
   ymin = 0.0;
   ymax = 5.0;
@@ -218,10 +254,12 @@ x29::plot3()
   pls->box("bcnstd", 14*24.0*60.0*60.0,14, "bcnstv", 1, 4);
 
   pls->col0(3);
-  pls->lab("Date", "Hours of television watched", "#frPLplot Example 29 - Hours of television watched in Dec 2005 / Jan 2006");
+  pls->lab("Date", "Hours of television watched", "@frPLplot Example 29 - Hours of television watched in Dec 2005 / Jan 2006");
   
   pls->col0(4);
 
+  // Rescale symbol size (used by plpoin) by 0.5
+  pls->ssym(0.0,0.5);
   pls->poin(npts, x, y, 2);
   pls->line(npts, x, y);
  
