@@ -1,4 +1,4 @@
-/* $Id: x13c.c 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: x13c.c 9142 2008-12-16 18:20:39Z andrewross $
 
 	Pie chart demo.
 */
@@ -41,7 +41,12 @@ main(int argc, const char *argv[])
 
     plinit();
 
-    plenv(0., 10., 0., 10., 1, -2);
+    pladv(0);
+    /* Ensure window has aspect ratio of one so circle is 
+     * plotted as a circle. */
+    plvasp(1.0);
+    plwind(0., 10., 0., 10.);
+    /* plenv(0., 10., 0., 10., 1, -2); */
     plcol0(2);
     /* n.b. all theta quantities scaled by 2*M_PI/500 to be integers to avoid
      * floating point logic problems. */
