@@ -1,4 +1,4 @@
-/* $Id: x17c.c 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: x17c.c 9272 2009-01-07 15:14:56Z andrewross $
 
  * Plots a simple stripchart with four pens.
  */
@@ -40,9 +40,13 @@ main(int argc, const char *argv[])
 
 /* If db is used the plot is much more smooth. However, because of the
    async X behaviour, one does not have a real-time scripcharter.
+   This is now disabled since it does not significantly improve the 
+   performance on new machines and makes it difficult to use this
+   example non-interactively since it requires an extra pleop call after
+   each call to plstripa.
 */
-    plsetopt("db", "");
-    plsetopt("np", "");
+    /*plsetopt("db", "");*/
+    /*plsetopt("np", "");*/
 
 /* User sets up plot completely except for window and data 
  * Eventually settings in place when strip chart is created will be
@@ -123,15 +127,17 @@ main(int argc, const char *argv[])
     dt = 0.1;
 
     for (n = 0; n < nsteps; n++) {
-#ifdef HAVE_USLEEP
+#ifdef PL_HAVE_USLEEP
 	usleep(10000);	/* wait a little (10 ms) to simulate time elapsing */
 #else
 # ifdef HAS_POLL
 	poll(0,0,10);
+# else
+	{ int i; for( i=0; i<1000000; i++ ); }
 # endif
 #endif
 	t = (double)n * dt;
-	noise = ((double)rand()/(RAND_MAX+1.0)) - 0.5;
+	noise = plrandd() - 0.5;
 	y1 = y1 + noise;
 	y2 = sin(t*M_PI/18.);
 	y3 = y2 * noise;
@@ -148,7 +154,9 @@ main(int argc, const char *argv[])
 	    plstripa(id1, 2, t, y3);
 	if (n%5)
 	    plstripa(id1, 3, t, y4);
-	pleop();  /* use double buffer (-db on command line) */
+
+        /* needed if using double buffering (-db on command line) */
+	/*pleop();*/  
     }
 
 /* Destroy strip chart and it's memory */
