@@ -1,4 +1,4 @@
-/* $Id: x21c.c 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: x21c.c 9278 2009-01-08 14:30:16Z andrewross $
 	Grid data demo
 
    Copyright (C) 2004  Joao Cardoso
@@ -22,7 +22,6 @@
 */
 
 #include "plcdemos.h"
-#include <time.h>
 
 #if !defined(HAVE_ISNAN)
 #  define isnan(x) ((x) != (x))
@@ -38,7 +37,7 @@
 static PLINT pts = 500;
 static PLINT xp = 25;
 static PLINT yp = 20;
-static PLINT nl = 15;
+static PLINT nl = 16;
 static int knn_order = 20;
 static PLFLT threshold = 1.001;
 static PLFLT wmin = -1e3;
@@ -156,10 +155,8 @@ main(int argc, const char *argv[])
   PLFLT *x, *y, *z, *clev;
   PLFLT *xg, *yg, **zg;
   PLFLT zmin, zmax, lzm, lzM;
-  long ct;
   int i, j, k;
   PLINT alg;
-  char ylab[40], xlab[40];
   char *title[] = {"Cubic Spline Approximation",
 		   "Delaunay Linear Interpolation",
 		   "Natural Neighbors Interpolation",
@@ -170,7 +167,7 @@ main(int argc, const char *argv[])
   PLFLT opt[] = {0., 0., 0., 0., 0., 0.};
 
   xm = ym = -0.2;
-  xM = yM = 0.8;
+  xM = yM = 0.6;
 
   plMergeOpts(options, "x21c options", NULL);
   plparseopts(&argc, argv, PL_PARSE_FULL);
@@ -183,6 +180,9 @@ main(int argc, const char *argv[])
 
   plinit();
 
+  /* Initialise random number generator */
+  plseed(5489);
+
   create_data(&x, &y, &z, pts); /* the sampled data */
   zmin = z[0];
   zmax = z[0];
@@ -197,11 +197,11 @@ main(int argc, const char *argv[])
   plAlloc2dGrid(&zg, xp, yp); /* the output grided data */
   clev = (PLFLT *) malloc(nl * sizeof(PLFLT));
 
-  sprintf(xlab, "Npts=%d gridx=%d gridy=%d", pts, xp, yp);
+  /* printf("Npts=%d gridx=%d gridy=%d", pts, xp, yp); */
   plcol0(1);
   plenv(xm, xM, ym, yM, 2, 0);
   plcol0(15);
-  pllab(xlab, "", "The original data");
+  pllab("X", "Y", "The original data sampling");
   plcol0(2);
   plpoin(pts, x, y, 5);
   pladv(0);
@@ -212,10 +212,7 @@ main(int argc, const char *argv[])
     pladv(0);
     for (alg=1; alg<7; alg++) {
 
-      ct = clock();
       plgriddata(x, y, z, pts, xg, xp, yg, yp, zg, alg, opt[alg-1]);
-      sprintf(xlab, "time=%ld ms", (clock() - ct)/1000);
-      sprintf(ylab, "opt=%.3f", opt[alg-1]);
 
       /* - CSA can generate NaNs (only interpolates?!).
        * - DTLI and NNI can generate NaNs for points outside the convex hull
@@ -258,19 +255,26 @@ main(int argc, const char *argv[])
 
       plMinMax2dGrid(zg, xp, yp, &lzM, &lzm);
 
+      lzm = MIN(lzm, zmin);
+      lzM = MAX(lzM, zmax);
+
+      /* Increase limits slightly to prevent spurious contours 
+       due to rounding errors */
+      lzm = lzm-0.01;
+      lzM = lzM+0.01;
+
       plcol0(1);
+
       pladv(alg);
 
       if (k == 0) {
 
-	lzm = MIN(lzm, zmin);
-	lzM = MAX(lzM, zmax);
 	for (i=0; i<nl; i++)
 	  clev[i] = lzm + (lzM-lzm)/(nl-1)*i;
 
 	plenv0(xm, xM, ym, yM, 2, 0);
 	plcol0(15);
-	pllab(xlab, ylab, title[alg-1]);
+	pllab("X", "Y", title[alg-1]);
 	plshades(zg, xp, yp, NULL, xm, xM, ym, yM,
 		 clev, nl, 1, 0, 1, plfill, 1, NULL, NULL);
 	plcol0(2);
@@ -281,19 +285,19 @@ main(int argc, const char *argv[])
 
 	cmap1_init();
 	plvpor(0.0, 1.0, 0.0, 0.9);
-	plwind(-1.0, 1.0, -1.0, 1.5);
+	plwind(-1.1, 0.75, -0.65, 1.20);
 	/*
-	 * For the comparition to be fair, all plots should have the
+	 * For the comparison to be fair, all plots should have the
 	 * same z values, but to get the max/min of the data generated
 	 * by all algorithms would imply two passes. Keep it simple.
 	 *
 	 * plw3d(1., 1., 1., xm, xM, ym, yM, zmin, zmax, 30, -60);
 	 */
 
-	plw3d(1., 1., 1., xm, xM, ym, yM, lzm, lzM, 30, -60);
-	plbox3("bnstu", ylab, 0.0, 0,
-	       "bnstu", xlab, 0.0, 0,
-	       "bcdmnstuv", "", 0.0, 4);
+	plw3d(1., 1., 1., xm, xM, ym, yM, lzm, lzM, 30, -40);
+	plbox3("bntu", "X", 0., 0,
+	       "bntu", "Y", 0., 0,
+	       "bcdfntu", "Z", 0.5, 0);
 	plcol0(15);
 	pllab("", "", title[alg-1]);
 	plot3dc(xg, yg, zg, xp, yp, DRAW_LINEXY | MAG_COLOR | BASE_CONT, clev, nl);
@@ -335,11 +339,6 @@ free_grid(PLFLT *xi, PLFLT *yi)
   free((void *)yi);
 }
 
-/* Function drand48() does not exist on Windows (MSVC/C++) and it is
-   deprecated under Linux, so use rand() instead
-*/
-#define drand48 (1.0/RAND_MAX)*(PLFLT)rand
-
 void
 create_data(PLFLT **xi, PLFLT **yi, PLFLT **zi, int pts)
 {
@@ -352,8 +351,8 @@ create_data(PLFLT **xi, PLFLT **yi, PLFLT **zi, int pts)
   *zi = z = (PLFLT *) malloc(pts * sizeof(PLFLT));
 
   for(i=0; i<pts; i++) {
-    xt = drand48();
-    yt = drand48();
+    xt = (xM-xm)*plrandd();
+    yt = (yM-ym)*plrandd();
     if (!randn) {
       *x = xt + xm;
       *y = yt + ym;
