@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x01.java 6815 2006-07-19 07:13:56Z andrewross $
+// $Id: x01.java 9135 2008-12-16 14:53:20Z andrewross $
 //---------------------------------------------------------------------------//
 
 //---------------------------------------------------------------------------//
@@ -56,9 +56,6 @@ class x01 {
      {
 
     // plplot initialization
-    // Divide page into 2x2 plots unless user overrides.
-
-        pls.ssub(2, 2);
 
     // Parse and process command line arguments.
 
@@ -73,7 +70,8 @@ class x01 {
 	System.out.println("PLplot library version: " + version);
 
     // Initialize PLplot.
-        pls.init();
+    // Divide page into 2x2 plots unless user overrides.
+        pls.star(2,2);
 
     // Select the multi-stroke font.
         if (fontset == 1) 
