@@ -37,6 +37,10 @@ my $y0 = sin ($dtr * sequence (361));
 
 plParseOpts (\@ARGV, PL_PARSE_SKIP | PL_PARSE_NOPROGRAM);
 
+# Set orientation to landscape - note not all device drivers
+# support this, in particular most interactive drivers do not
+plsori(1);
+
 # Initialize plplot
 
 plinit ();
@@ -65,13 +69,21 @@ for my $i (0 .. 11) {
 
   pljoin (0, 0, $dx, $dy);
 
+  if ($theta < 9.99) {
+      $offset = 0.45;
+  } elsif ($theta < 99.9) {
+      $offset = 0.30;
+  } else {
+      $offset = 0.15;
+  }
+
   # Write labels for angle
   # Slightly off zero to avoid floating point logic flips at 90 and 270 deg
 
   if ($dx >= -0.00001) {
-    plptex ($dx, $dy, $dx, $dy, -0.15, int ($theta));
+    plptex ($dx, $dy, $dx, $dy, -$offset, int ($theta));
   } else {
-    plptex ($dx, $dy, -$dx, -$dy, 1.15, int ($theta));
+    plptex ($dx, $dy, -$dx, -$dy, (1.+$offset), int ($theta));
   }
 }
 
