@@ -1,5 +1,5 @@
 #----------------------------------------------------------------------------
-# $Id: x02.tcl 6142 2005-03-23 12:27:09Z mlebrun $
+# $Id: x02.tcl 8674 2008-08-19 10:54:16Z andrewross $
 #----------------------------------------------------------------------------
 
 proc x02 {{w loopback}} {
@@ -10,7 +10,7 @@ proc x02 {{w loopback}} {
 # Restore defaults
     $w cmd plssub 1 1
     $w cmd plfont 1
-    $w cmd plcol0 1
+    # $w cmd plcol0 1
 }
 
 # Demonstrates multiple windows and default color map 0 palette.
@@ -72,20 +72,37 @@ proc x02_demo2 {w} {
         set s 1.0
 
         plhlsrgb $h $l $s r1 g1 b1
+	# puts [format "%3d %15.9f %15.9f %15.9f %15.9f %15.9f %15.9f" $i1 $h $l $s $r1 $g1 $b1]
         if $see_the_bug {
-            r $i1 = [expr int($r1 * 255)]
-            g $i1 = [expr int($g1 * 255)]
-            b $i1 = [expr int($b1 * 255)]
+            r $i1 = [expr int($r1 * 255.001)]
+            g $i1 = [expr int($g1 * 255.001)]
+            b $i1 = [expr int($b1 * 255.001)]
         } else {
-            set r2 [expr int($r1 * 255)]
-            set g2 [expr int($g1 * 255)]
-            set b2 [expr int($b1 * 255)]
+            set r2 [expr int($r1 * 255.001)]
+            set g2 [expr int($g1 * 255.001)]
+            set b2 [expr int($b1 * 255.001)]
+  	    # puts [format "%3d %3d %3d %3d" $i1 $r2 $g2 $b2]
             plscol0 $i1 $r2 $g2 $b2
         }
     }
 
     if $see_the_bug {
-        plscmap0 r g b $ntot
+       # Load default cmap0 colors into our custom set
+       for {set i 0} {$i < $offset} {incr i} {
+	  plgcol0 $i r1 g1 b1
+	  r $i = [expr int($r1)]
+	  g $i = [expr int($g1)]
+	  b $i = [expr int($b1)]
+       }
+       # temporary
+       for {set i 0} {$i < $ntot} {incr i} {
+	  set r1 [expr [r $i]]
+	  set g1 [expr [g $i]]
+	  set b1 [expr [b $i]]
+  	  puts [format "%3d %3d %3d %3d" $i $r1 $g1 $b1]
+       }
+       # The following call currently segfaults.
+       plscmap0 r g b $ntot
     }
 
     x02_draw_windows $w 100 $offset
