@@ -1,4 +1,4 @@
-/* $Id: plcore.h 8196 2008-01-30 15:59:12Z andrewross $
+/* $Id: plcore.h 9184 2008-12-18 08:41:56Z smekal $
 
 	Contains declarations for core plplot data structures.  This file
 	should be included only by plcore.c.
@@ -33,10 +33,14 @@
 #include "disptab.h"
 
 #ifdef ENABLE_DYNDRIVERS
-#include <ltdl.h>
-typedef lt_ptr (*PLDispatchInit)( PLDispatchTable *pdt );
+  #ifndef LTDL_WIN32
+    #include <ltdl.h>
+  #else
+    #include "ltdl_win32.h"
+  #endif
+  typedef lt_ptr (*PLDispatchInit)( PLDispatchTable *pdt );
 #else
-typedef void (*PLDispatchInit)( PLDispatchTable *pdt );
+  typedef void (*PLDispatchInit)( PLDispatchTable *pdt );
 #endif
 
 #ifdef HAVE_LIBUNICODE
@@ -258,6 +262,9 @@ static PLDispatchInit static_device_initializers[] = {
 #if defined(PLD_wxwidgets) && !defined(ENABLE_DYNDRIVERS)
     plD_dispatch_init_wxwidgets,
 #endif
+#if defined(PLD_wxpng) && !defined(ENABLE_DYNDRIVERS)
+    plD_dispatch_init_wxpng,
+#endif
 #if defined(PLD_svg) && !defined(ENABLE_DYNDRIVERS)
     plD_dispatch_init_svg,
 #endif
@@ -286,6 +293,9 @@ static PLDispatchInit static_device_initializers[] = {
 #if defined(PLD_memcairo) && !defined(ENABLE_DYNDRIVERS)
     plD_dispatch_init_memcairo,
 #endif
+#if defined(PLD_extcairo) && !defined(ENABLE_DYNDRIVERS)
+    plD_dispatch_init_extcairo,
+#endif
 
     NULL
 };
