@@ -1,4 +1,4 @@
-/* $Id: plplot.h 8196 2008-01-30 15:59:12Z andrewross $
+/* $Id: plplot.h 9284 2009-01-08 20:47:39Z andrewross $
 
     Macros and prototypes for the PLplot package.  This header file must
     be included by all user codes.
@@ -90,6 +90,15 @@
 #endif
 #endif
 
+#if 0
+#if defined(__GNUC__) && __GNUC__ > 3
+  /* If gcc 4.x, then turn off all visibility of symbols unless
+   * specified as visible using PLDLLIMPEXP. */
+  /*#pragma GCC visibility push(hidden)*/
+  /* temporary until issues with above hidden can be sorted out */
+  #pragma GCC visibility push(default)
+#endif
+#endif
 /* Make sure Unix systems define "__unix" */
 
 #if defined(SX)	||				/* NEC Super-UX */      \
@@ -149,14 +158,24 @@ typedef float PLFLT;
 (defined(__cplusplus) && defined(HAVE_CXX_STDINT_H))
 #include <stdint.h>
 /* This is apparently portable if stdint.h exists. */
-typedef uint32_t PLUNICODE;
+typedef uint32_t PLUINT;
 typedef int32_t PLINT;
+typedef int64_t PLINT64;
 #else
 /* A reasonable back-up in case stdint.h does not exist on the platform. */
-typedef unsigned int PLUNICODE;
+typedef unsigned int PLUINT;
 typedef int PLINT;
+typedef __int64 PLINT64;
+/*
+typedef unsigned int PLUINT;
+typedef int PLINT;
+typedef long long PLINT64;
+*/
 #endif
 
+/* For identifying unicode characters */
+typedef PLUINT PLUNICODE;
+
 /* For identifying logical (boolean) arguments */
 typedef PLINT PLBOOL;
 
@@ -469,7 +488,6 @@ typedef struct {
 #define    pl_setcontlabelformat c_pl_setcontlabelformat
 #define    pl_setcontlabelparam c_pl_setcontlabelparam
 #define    pladv	c_pladv
-#define    plarrows	c_plarrows
 #define    plaxes	c_plaxes
 #define    plbin	c_plbin
 #define    plbop	c_plbop
@@ -507,6 +525,7 @@ typedef struct {
 #define    plgfam	c_plgfam
 #define    plgfci	c_plgfci
 #define    plgfnam	c_plgfnam
+#define    plgfont      c_plgfont
 #define    plglevel	c_plglevel
 #define    plgpage	c_plgpage
 #define    plgra	c_plgra
@@ -522,6 +541,8 @@ typedef struct {
 #define    plhist	c_plhist
 #define    plhls        c_plhls
 #define    plhlsrgb     c_plhlsrgb
+#define    plimage	c_plimage
+#define    plimagefr	c_plimagefr
 #define    plinit	c_plinit
 #define    pljoin	c_pljoin
 #define    pllab	c_pllab
@@ -548,6 +569,7 @@ typedef struct {
 #define    plpsty	c_plpsty
 #define    plptex	c_plptex
 #define    plptex3	c_plptex3
+#define    plrandd	c_plrandd
 #define    plreplot	c_plreplot
 #define    plrgb	c_plrgb
 #define    plrgb1	c_plrgb1
@@ -573,11 +595,13 @@ typedef struct {
 #define    plsdiori	c_plsdiori
 #define    plsdiplt	c_plsdiplt
 #define    plsdiplz	c_plsdiplz
+#define    plseed	c_plseed
 #define    plsesc	c_plsesc
 #define    plsetopt	c_plsetopt
 #define    plsfam	c_plsfam
 #define    plsfci	c_plsfci
 #define    plsfnam	c_plsfnam
+#define    plsfont      c_plsfont
 #define    plshade	c_plshade
 #define    plshade1	c_plshade1
 #define    plshades	c_plshades
@@ -666,10 +690,6 @@ c_pladv(PLINT page);
 
 /* simple arrow plotter. */
 
-PLDLLIMPEXP void
-c_plarrows(PLFLT *u, PLFLT *v, PLFLT *x, PLFLT *y, PLINT n,
-           PLFLT scale, PLFLT dx, PLFLT dy) ;
-
 PLDLLIMPEXP void
 c_plvect(PLFLT **u, PLFLT **v, PLINT nx, PLINT ny, PLFLT scale,
 	void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
@@ -908,6 +928,11 @@ c_plgfam(PLINT *p_fam, PLINT *p_num, PLINT *p_bmax);
 PLDLLIMPEXP void
 c_plgfnam(char *fnam);
 
+/* Get the current font family, style and weight */
+
+PLDLLIMPEXP void
+c_plgfont(PLINT *p_family, PLINT *p_style, PLINT *p_weight);
+
 /* Get the (current) run level.  */
 
 PLDLLIMPEXP void
@@ -994,11 +1019,6 @@ PLDLLIMPEXP void
 c_plhist(PLINT n, PLFLT *data, PLFLT datmin, PLFLT datmax,
 	 PLINT nbin, PLINT opt);
 
-/* Set current color (map 0) by hue, lightness, and saturation. */
-
-PLDLLIMPEXP void
-c_plhls(PLFLT h, PLFLT l, PLFLT s);
-
 /* Functions for converting between HLS and RGB color space */
 
 PLDLLIMPEXP void
@@ -1078,7 +1098,7 @@ c_plmtex(const char *side, PLFLT disp, PLFLT pos, PLFLT just,
 PLDLLIMPEXP void
 c_plmtex3(const char *side, PLFLT disp, PLFLT pos, PLFLT just,
 	 const char *text);
-	 
+	
 /* Plots a 3-d representation of the function z[x][y]. */
 
 PLDLLIMPEXP void
@@ -1167,24 +1187,20 @@ c_plptex(PLFLT x, PLFLT y, PLFLT dx, PLFLT dy, PLFLT just, const char *text);
 /* Prints out "text" at world cooordinate (x,y,z). */
 
 PLDLLIMPEXP void
-c_plptex3(PLFLT wx, PLFLT wy, PLFLT wz, PLFLT dx, PLFLT dy, PLFLT dz, 
+c_plptex3(PLFLT wx, PLFLT wy, PLFLT wz, PLFLT dx, PLFLT dy, PLFLT dz,
 	     PLFLT sx, PLFLT sy, PLFLT sz, PLFLT just, const char *text);
 
+/* Random number generator based on Mersenne Twister.
+   Obtain real random number in range [0,1]. */
+
+PLDLLIMPEXP PLFLT
+c_plrandd(void);
+
 /* Replays contents of plot buffer to current device/file. */
 
 PLDLLIMPEXP void
 c_plreplot(void);
 
-/* Set line color by red, green, blue from  0. to 1. */
-
-PLDLLIMPEXP void
-c_plrgb(PLFLT r, PLFLT g, PLFLT b);
-
-/* Set line color by 8 bit RGB values. */
-
-PLDLLIMPEXP void
-c_plrgb1(PLINT r, PLINT g, PLINT b);
-
 /* Functions for converting between HLS and RGB color space */
 
 PLDLLIMPEXP void
@@ -1302,6 +1318,11 @@ c_plsdiplt(PLFLT xmin, PLFLT ymin, PLFLT xmax, PLFLT ymax);
 PLDLLIMPEXP void
 c_plsdiplz(PLFLT xmin, PLFLT ymin, PLFLT xmax, PLFLT ymax);
 
+/* Set seed for internal random number generator */
+
+PLDLLIMPEXP void
+c_plseed(unsigned int s);
+
 /* Set the escape character for text strings. */
 
 PLDLLIMPEXP void
@@ -1322,6 +1343,11 @@ c_plsfci(PLUNICODE fci);
 PLDLLIMPEXP void
 c_plsfnam(const char *fnam);
 
+/* Set the current font family, style and weight */
+
+PLDLLIMPEXP void
+c_plsfont(PLINT family, PLINT style, PLINT weight);
+
 /* Shade region. */
 
 PLDLLIMPEXP void
@@ -1447,12 +1473,22 @@ c_plstripc(PLINT *id, const char *xspec, const char *yspec,
 PLDLLIMPEXP void
 c_plstripd(PLINT id);
 
-  /* plots a 2d image (or a matrix too large for plshade() ) */
+/* plots a 2d image (or a matrix too large for plshade() ) */
 
 PLDLLIMPEXP void
-plimage( PLFLT **data, PLINT nx, PLINT ny,
-	 PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT zmin, PLFLT zmax,
-	 PLFLT Dxmin, PLFLT Dxmax, PLFLT Dymin, PLFLT Dymax);
+c_plimagefr(PLFLT **idata, PLINT nx, PLINT ny,
+        PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT zmin, PLFLT zmax,
+        PLFLT valuemin, PLFLT valuemax,
+        void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
+        PLPointer pltr_data);
+
+/* plots a 2d image (or a matrix too large for plshade() ) - colors
+   automatically scaled */
+
+PLDLLIMPEXP void
+c_plimage(PLFLT **idata, PLINT nx, PLINT ny,
+        PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT zmin, PLFLT zmax,
+        PLFLT Dxmin, PLFLT Dxmax, PLFLT Dymin, PLFLT Dymax);
 
 /* Set up a new line style */
 
@@ -1508,7 +1544,7 @@ c_plszax(PLINT digmax, PLINT digits);
 PLDLLIMPEXP void
 c_pltext(void);
 
-/* Set the format for date / time labels */ 
+/* Set the format for date / time labels */
 
 PLDLLIMPEXP void
 c_pltimefmt(const char *fmt);
@@ -1553,7 +1589,7 @@ c_plwid(PLINT width);
 PLDLLIMPEXP void
 c_plwind(PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax);
 
-/*  set xor mode; mode = 1-enter, 0-leave, status = 0 if not interactive device  */
+/* Set xor mode; mode = 1-enter, 0-leave, status = 0 if not interactive device  */
 
 PLDLLIMPEXP void
 c_plxormod(PLBOOL mode, PLBOOL *status);
@@ -1753,7 +1789,7 @@ plGetInt(const char *s);
 PLDLLIMPEXP PLFLT
 plGetFlt(const char *s);
 
-	/* Nice way to allocate space for a vectored 2d grid */
+/* Nice way to allocate space for a vectored 2d grid */
 
 /* Allocates a block of memory for use as a 2-d grid of PLFLT's.  */
 
@@ -1791,8 +1827,37 @@ plHLS_RGB(PLFLT h, PLFLT l, PLFLT s, PLFLT *p_r, PLFLT *p_g, PLFLT *p_b);
 
 PLDLLIMPEXP void
 plRGB_HLS(PLFLT r, PLFLT g, PLFLT b, PLFLT *p_h, PLFLT *p_l, PLFLT *p_s);
+
+PLDLLIMPEXP void
+plarrows(PLFLT *u, PLFLT *v, PLFLT *x, PLFLT *y, PLINT n,
+           PLFLT scale, PLFLT dx, PLFLT dy) ;
+
+/* These functions are depreciated and only retained for backwards
+ * compatibility - do not use in new code. */
+
+/* Set current color (map 0) by hue, lightness, and saturation. */
+
+PLDLLIMPEXP void
+c_plhls(PLFLT h, PLFLT l, PLFLT s);
+
+/* Set line color by red, green, blue from  0. to 1. */
+
+PLDLLIMPEXP void
+c_plrgb(PLFLT r, PLFLT g, PLFLT b);
+
+/* Set line color by 8 bit RGB values. */
+
+PLDLLIMPEXP void
+c_plrgb1(PLINT r, PLINT g, PLINT b);
+
+
 #ifdef __cplusplus
 }
 #endif
+#if 0
+#if defined(__GNUC__) && __GNUC__ > 3
+  #pragma GCC visibility pop
+#endif
+#endif
 
 #endif	/* __PLPLOT_H__ */
