@@ -1,4 +1,4 @@
-/* $Id: plplotP.h 8082 2007-12-12 15:44:17Z andrewross $
+/* $Id: plplotP.h 8942 2008-10-21 01:42:57Z airwin $
 
     Internal (private) macros and prototypes for the PLplot package.  This
     header file must be included before all others, including system header
@@ -116,7 +116,7 @@ typedef char * caddr_t;
 #if defined(PLPLOT_WINTK)
 #elif defined(WIN32) &! defined (__GNUC__)
 /* Redefine tmpfile()! (AM)*/
-#define tmpfile w32_tmpfile
+/* #define tmpfile w32_tmpfile */
 #else
 #include <unistd.h>
 #endif
@@ -132,21 +132,25 @@ typedef char * caddr_t;
    When  the dirent.h file will be fixed upstream by Apple Inc, this should
    go away. */
 # ifdef NEED_SYS_TYPE_H
-#   include <sys/types.h>
+#  include <sys/types.h>
 # endif
 # include <dirent.h>
 # define NAMLEN(dirent) strlen((dirent)->d_name)
 #else
-# define dirent direct
-# define NAMLEN(dirent) (dirent)->d_namlen
-# if HAVE_SYS_NDIR_H
-#  include <sys/ndir.h>
-# endif
-# if HAVE_SYS_DIR_H
-#  include <sys/dir.h>
-# endif
-# if HAVE_NDIR_H
-#  include <ndir.h>
+# if defined(_MSC_VER)
+#  include "dirent_msvc.h"
+# else
+#  define dirent direct
+#  define NAMLEN(dirent) (dirent)->d_namlen
+#  if HAVE_SYS_NDIR_H
+#   include <sys/ndir.h>
+#  endif
+#  if HAVE_SYS_DIR_H
+#   include <sys/dir.h>
+#  endif
+#  if HAVE_NDIR_H
+#   include <ndir.h>
+#  endif
 # endif
 #endif
 
@@ -174,6 +178,8 @@ typedef char * caddr_t;
 #define pl_fgetpos(a,b) (-1L == (*b = ftell(a)))
 #endif
 
+#include "pldll.h"
+
 /* Include all externally-visible definitions and prototypes */
 /* plplot.h also includes some handy system header files */
 
@@ -244,6 +250,24 @@ extern PLDLLIMPEXP_DATA(PLStream *)plsc;
 
 #define PL_UNDEFINED -9999999
 
+/* Declarations for save string functions */
+
+#ifdef PL_HAVE_SNPRINTF
+  /* In case only _snprintf is declared (as for Visual C++ and
+     Borland compiler toolset) we redefine the function names */
+  #ifdef _PL_HAVE_SNPRINTF
+    #define snprintf _snprintf
+    #define snscanf _snscanf
+  #endif /* _PL_HAVE_SNPRINTF */
+#else /* !PL_HAVE_SNPRINTF */
+  /* declare dummy functions which just call the unsafe
+     functions ignoring the size of the string */
+  int plsnprintf( char *buffer, int n, const char *format, ... );
+  int plsnscanf( const char *buffer, int n, const char *format, ... );
+  #define snprintf plsnprintf
+  #define snscanf plsnscanf
+#endif /* PL_HAVE_SNPRINTF */
+
 /*--------------------------------------------------------------------------*\
  *                       PLPLOT control macros
 \*--------------------------------------------------------------------------*/
@@ -441,7 +465,7 @@ void
 plP_hex2fci(unsigned char hexdigit, unsigned char hexpower, PLUNICODE *pfci);
 
 /* Retrieves hex digit value from FCI (font characterization integer). */
-void
+PLDLLIMPEXP void
 plP_fci2hex(PLUNICODE fci, unsigned char *phexdigit, unsigned char hexpower);
 
 /* Pattern fills in software the polygon bounded by the input points. */
@@ -482,12 +506,12 @@ plfontrel(void);
 
 /* A replacement for strdup(), which isn't portable. */
 
-char PLDLLIMPEXP *
+PLDLLIMPEXP char *
 plstrdup(const char *src);
 
 /* Bin up cmap 1 space and assign colors to make inverse mapping easy. */
 
-void
+PLDLLIMPEXP void
 plcmap1_calc(void);
 
 /* Draws a slanting tick at position (mx,my) (measured in mm) of */
@@ -515,7 +539,7 @@ plytik(PLINT x, PLINT y, PLINT left, PLINT right);
   /* Driver interface filter --
      passes all coordinates through a variety of filters. */
 
-void
+PLDLLIMPEXP void
 difilt(PLINT *, PLINT *, PLINT,
        PLINT *, PLINT *, PLINT *, PLINT *);
 
@@ -562,7 +586,7 @@ enum {DRV_INT, DRV_FLT, DRV_STR};
 
   /* parse driver specific options, as in -drvopt <option[=value]>* */
 
-int
+PLDLLIMPEXP int
 plParseDrvOpts(DrvOpt *);
 
   /* give help on driver specific options */
@@ -600,6 +624,11 @@ cont_store(PLFLT **f, PLINT nx, PLINT ny,
 void
 cont_clean_store(CONT_LEVEL *ct);
 
+/* Get the viewport boundaries in world coordinates, expanded slightly */
+
+void
+plP_xgvpw(PLFLT *p_xmin, PLFLT *p_xmax, PLFLT *p_ymin, PLFLT *p_ymax);
+
 /* Get x-y domain in world coordinates for 3d plots */
 
 void
@@ -653,7 +682,7 @@ plP_gpixmm(PLFLT *p_x, PLFLT *p_y);
 
 /* All the drivers call this to set physical pixels/mm. */
 
-void
+PLDLLIMPEXP void
 plP_setpxl(PLFLT xpmm0, PLFLT ypmm0);
 
 /* Get background parameters (including line width) for 3d plot. */
@@ -693,7 +722,7 @@ plP_drawor_poly(PLFLT *x, PLFLT *y, PLINT n);
 
 /* Sets up physical limits of plotting device. */
 
-void
+PLDLLIMPEXP void
 plP_setphy(PLINT xmin, PLINT xmax, PLINT ymin, PLINT ymax);
 
 /* Set up the subpage boundaries according to the current subpage selected */
@@ -843,10 +872,15 @@ plP_w3wcx(PLFLT x, PLFLT y, PLFLT z);
 PLFLT
 plP_w3wcy(PLFLT x, PLFLT y, PLFLT z);
 
-/* Returns the rotation and shear angle from a plplot transformation matrix */
+/* 3-d coords to 2-d projection (z) */
 
-void
-plRotationShear(PLFLT *xFormMatrix, PLFLT *rotation, PLFLT *shear);
+PLFLT
+plP_w3wcz(PLFLT x, PLFLT y, PLFLT z);
+
+/* Returns the rotation and shear angle and stride from a plplot transformation matrix */
+
+PLDLLIMPEXP void
+plRotationShear(PLFLT *xFormMatrix, PLFLT *rotation, PLFLT *shear, PLFLT *stride);
 
 
     /* Driver calls */
@@ -874,7 +908,8 @@ plP_fill(short *x, short *y, PLINT npts);
 /* draw image */
 
 void
-plP_image(short *x, short *y, unsigned short *z, PLINT nx, PLINT ny, PLFLT xmin, PLFLT ymin, PLFLT dx, PLFLT dy, unsigned short zmin, unsigned short zmax);
+plP_image(PLFLT *z, PLINT nx, PLINT ny, PLFLT xmin, PLFLT ymin, PLFLT dx, PLFLT dy,
+        void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer), PLPointer pltr_data);
 
 /* End of page */
 
@@ -898,7 +933,7 @@ plP_state(PLINT op);
 
 /* Escape function, for driver-specific commands. */
 
-void
+PLDLLIMPEXP void
 plP_esc(PLINT op, void *ptr);
 
 /* Set up plot window parameters. */
@@ -913,17 +948,17 @@ plLibOpen(const char *fn);
 
 /* Does required startup initialization of library.  */
 
-void
+PLDLLIMPEXP void
 pllib_init(void);
 
 /* Does preliminary setup of device driver. */
 
-void
+PLDLLIMPEXP void
 pllib_devinit(void);
 
 /* Utility to copy one PLColor to another. */
 
-void
+PLDLLIMPEXP void
 pl_cpcolor(PLColor *to, PLColor *from);
 
 /* Does required startup initialization of a stream.  */
@@ -934,7 +969,7 @@ plstrm_init(void);
 /* Builds a list of the active devices/streams by device name */
 
 void
-plP_getinitdriverlist(char *names);
+PLDLLIMPEXP plP_getinitdriverlist(char *names);
 
 /* Checks a give list of device names against active streams and returns the number of matches */
 
@@ -952,13 +987,14 @@ RestoreWrite2BufferPixmap(void);
 void
 grimage(short *x, short *y, unsigned short *z, PLINT nx, PLINT ny);
 
-int PLDLLIMPEXP
+PLDLLIMPEXP int
 plInBuildTree();
 
 void
-plimageslow(short *x, short *y, unsigned short *data, PLINT nx, PLINT ny,
-	    PLFLT xmin, PLFLT ymin, PLFLT dx, PLFLT dy,
-	    unsigned short zmin,  unsigned short zmax);
+plimageslow(PLFLT *idata, PLINT nx, PLINT ny,
+        PLFLT xmin, PLFLT ymin, PLFLT dx, PLFLT dy,
+        void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
+        PLPointer pltr_data);
 
 typedef struct {
   PLFLT xmin, ymin, dx, dy;} IMG_DT;
@@ -970,7 +1006,7 @@ typedef struct {
  * and vector transformations.
  * This is not currently intended to be called direct by the user
  */
-void PLDLLIMPEXP
+PLDLLIMPEXP void
 plfvect(PLFLT (*plf2eval) (PLINT, PLINT, PLPointer),
 		PLPointer f2evalv_data, PLPointer f2evalc_data,
 		PLINT nx, PLINT ny, PLFLT scale,
@@ -991,7 +1027,7 @@ typedef struct
 } FCI_to_FontName_Table;
 
 /* Internal function to obtain a pointer to a valid font name. */
-char *
+PLDLLIMPEXP char *
 plP_FCI2FontName ( PLUNICODE fci,
 		   const FCI_to_FontName_Table lookup[], const int nlookup);
 
@@ -1001,7 +1037,7 @@ void
 plP_FreeDrvOpts();
 
 /* Convert a ucs4 unichar to utf8 char string*/
-int
+PLDLLIMPEXP int
 ucs4_to_utf8(PLUNICODE unichar, char *ptr);
 
 /*
@@ -1026,10 +1062,26 @@ plio_fgets(char *, int, FILE *);
 /* get drivers directory */
    
 #ifdef ENABLE_DYNDRIVERS
-char*
+PLDLLIMPEXP char* 
 plGetDrvDir (void);
 #endif
 
+#ifdef HAVE_FREETYPE
+PLDLLIMPEXP void 
+plD_FreeType_init(PLStream *);
+
+PLDLLIMPEXP void 
+plD_render_freetype_text (PLStream *, EscText *);
+
+PLDLLIMPEXP void 
+plD_FreeType_Destroy(PLStream *);
+
+PLDLLIMPEXP void 
+pl_set_extended_cmap0(PLStream *, int, int);
+
+#endif
+
+
 #ifdef __cplusplus
 }
 #endif
