@@ -1,4 +1,4 @@
-/* $Id: plstrm.h 8057 2007-12-03 17:08:51Z andrewross $
+/* $Id: plstrm.h 8899 2008-10-14 20:44:40Z smekal $
  *
  *	Contains declarations for PLStream and PLDev structs.
  *	Also prototypes for stream & device utility functions.
@@ -661,7 +661,7 @@ typedef struct {
     PLFLT base3x, base3y, basecx, basecy;
     PLFLT domxmi, domxma, domymi, domyma;
     PLFLT zzscl, ranmi, ranma;
-    PLFLT cxx, cxy, cyx, cyy, cyz;
+  PLFLT cxx, cxy, cyx, cyy, cyz, czx, czy, czz;
 
 /* Variables for keeping track of windows on a page. */
 
@@ -729,12 +729,12 @@ plgpls(PLStream **p_pls);
 
 /* Initializes device cmap 1 entry by interpolation from pls->cmap1 entries */
 
-void
+PLDLLIMPEXP void
 plcol_interp(PLStream *pls, PLColor *newcolor, int i, int ncol);
 
 /* Opens file for output, prompting if not set. */
 
-void
+PLDLLIMPEXP void
 plOpenFile(PLStream *pls);
 
 /* Sets up next file member name (in pls->FileName), but does not open it. */
@@ -749,28 +749,28 @@ plP_sfnam(PLStream *pls, const char *fnam);
 
 /* Initializes family file parameters. */
 
-void
+PLDLLIMPEXP void
 plFamInit(PLStream *pls);
 
 /* Starts new member file of family file set if necessary. */
 
-void
+PLDLLIMPEXP void
 plGetFam(PLStream *pls);
 
 /* Rotates physical coordinates if necessary for given orientation. */
 
-void
+PLDLLIMPEXP void
 plRotPhy(PLINT orient, PLINT xmin, PLINT ymin, PLINT xmax, PLINT ymax,
 	 PLINT *px, PLINT *py);
 
 /* Allocates a standard PLDev structure for device-specific data */
 
-PLDev *
+PLDLLIMPEXP PLDev *
 plAllocDev(PLStream *pls);
 
 /* Just fills in the PLGraphicsIn with appropriate initial values. */
 
-void
+PLDLLIMPEXP void
 plGinInit(PLGraphicsIn *gin);
 
 #ifdef __cplusplus
