@@ -1,4 +1,4 @@
-/* $Id: plargs.c 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: plargs.c 8487 2008-06-25 08:36:42Z smekal $
 
     Copyright 1993, 1994, 1995
     Maurice LeBrun			mjl@dino.ph.utexas.edu
@@ -624,7 +624,7 @@ typedef struct DrvOptCmd {
 } DrvOptCmd;
 
 /* the variable where opt_drvopt() stores the driver specific command line options */
-static DrvOptCmd drv_opt;
+static DrvOptCmd drv_opt = { NULL, NULL, NULL };
 
 static int  tables = 1;
 
@@ -759,10 +759,6 @@ c_plparseopts(int *p_argc, const char **argv, PLINT mode)
     mode_nodash    = mode & PL_PARSE_NODASH;
     mode_skip      = mode & PL_PARSE_SKIP;
 
-    /* Initialize the driver specific option linked structure */
-    drv_opt.option  = drv_opt.value  = NULL;
-    drv_opt.next  = NULL;
-
     myargc = (*p_argc);
     argend = argv + myargc;
 
@@ -1228,7 +1224,8 @@ plParseDrvOpts(DrvOpt *acc_opt) {
   DrvOpt *t;
   int fl;
   char msg[80];
-
+  memset( msg, '\0', sizeof(msg) );
+  
   if (!drv_opt.option)
     return 1;
 
@@ -1249,7 +1246,7 @@ plParseDrvOpts(DrvOpt *acc_opt) {
 
 	case DRV_INT:
 	  if (sscanf(drvp->value, "%d", (int *)t->var_ptr) != 1) {
-	    sprintf(msg,"Incorrect argument to '%s' option", drvp->option);
+	    snprintf(msg, sizeof(msg)-1, "Incorrect argument to '%s' option", drvp->option);
 	    plexit(msg);
 	  }
 #ifdef DEBUG
@@ -1259,7 +1256,7 @@ plParseDrvOpts(DrvOpt *acc_opt) {
 
 	case DRV_FLT:
 	  if (sscanf(drvp->value, "%f", (float *)t->var_ptr) != 1) {
-	    sprintf(msg,"Incorrect argument to '%s' option", drvp->option);
+	    snprintf(msg, sizeof(msg)-1, "Incorrect argument to '%s' option", drvp->option);
 	    plexit(msg);
 	  }
 #ifdef DEBUG
@@ -1272,7 +1269,7 @@ plParseDrvOpts(DrvOpt *acc_opt) {
     }
 
     if (!fl) {
-      sprintf(msg, "Option '%s' not recognized.\n\nRecognized options for this driver are:\n", drvp->option);
+      snprintf(msg, sizeof(msg)-1, "Option '%s' not recognized.\n\nRecognized options for this driver are:\n", drvp->option);
       plwarn(msg);
       plHelpDrvOpts(acc_opt);
       plexit("");
@@ -1311,9 +1308,6 @@ void
 plP_FreeDrvOpts() {
   DrvOptCmd *drvp, *drvpl;
 
-  if (!drv_opt.option) 
-    return;
-
   drvp = &drv_opt;
   do {
     drvpl = drvp;
@@ -1327,6 +1321,11 @@ plP_FreeDrvOpts() {
       free(drvpl);
 
   } while(drvp != NULL);
+  
+  /* initialize drv_opt if it's used again */
+  drv_opt.option=NULL;
+  drv_opt.value=NULL;
+  drv_opt.next=NULL;  
 }
 
 
