@@ -1,4 +1,4 @@
-/* $Id: plbuf.c 7348 2007-02-04 05:05:17Z aroach $
+/* $Id: plbuf.c 9110 2008-12-15 09:50:50Z andrewross $
 
     Handle plot buffer.
 
@@ -315,10 +315,11 @@ plbuf_text(PLStream *pls, EscText *text)
  *
  * Functions:
  *
- *	PLESC_FILL	Fill polygon
- *	PLESC_SWIN	Set plot window parameters
- *      PLESC_IMAGE     Draw image
- *      PLESC_HAS_TEXT  Draw PostScript text
+ *	PLESC_FILL	    Fill polygon
+ *	PLESC_SWIN	    Set plot window parameters
+ *  PLESC_IMAGE     Draw image
+ *  PLESC_HAS_TEXT  Draw PostScript text
+ *	PLESC_CLEAR	    Clear Background
 \*--------------------------------------------------------------------------*/
 
 void
@@ -495,12 +496,14 @@ rdbuf_state(PLStream *pls)
     case PLSTATE_COLOR0:{
 	short icol0;
 	U_CHAR r, g, b;
+        PLFLT a;
 
 	rd_data(pls, &icol0, sizeof(short));
 	if (icol0 == PL_RGB_COLOR) {
 	    rd_data(pls, &r, sizeof(U_CHAR));
 	    rd_data(pls, &g, sizeof(U_CHAR));
 	    rd_data(pls, &b, sizeof(U_CHAR));
+            a = 1.0;
 	}
 	else {
 	    if ((int) icol0 >= pls->ncol0) {
@@ -512,11 +515,13 @@ rdbuf_state(PLStream *pls)
 	    r = pls->cmap0[icol0].r;
 	    g = pls->cmap0[icol0].g;
 	    b = pls->cmap0[icol0].b;
+	    a = pls->cmap0[icol0].a;
 	}
 	pls->icol0 = icol0;
 	pls->curcolor.r = r;
 	pls->curcolor.g = g;
 	pls->curcolor.b = b;
+	pls->curcolor.a = a;
 
 	plP_state(PLSTATE_COLOR0);
 	break;
@@ -531,6 +536,7 @@ rdbuf_state(PLStream *pls)
 	pls->curcolor.r = pls->cmap1[icol1].r;
 	pls->curcolor.g = pls->cmap1[icol1].g;
 	pls->curcolor.b = pls->cmap1[icol1].b;
+	pls->curcolor.a = pls->cmap1[icol1].a;
 
 	plP_state(PLSTATE_COLOR1);
 	break;
@@ -560,10 +566,11 @@ rdbuf_state(PLStream *pls)
  *
  * Functions:
  *
- *	PLESC_FILL	Fill polygon
- *	PLESC_SWIN	Set plot window parameters
- *      PLESC_IMAGE     Draw image
- *      PLESC_HAS_TEXT  Draw PostScript text
+ *	PLESC_FILL	    Fill polygon
+ *	PLESC_SWIN	    Set plot window parameters
+ *  PLESC_IMAGE     Draw image
+ *  PLESC_HAS_TEXT  Draw PostScript text
+ *	PLESC_CLEAR	    Clear Background
 \*--------------------------------------------------------------------------*/
 
 static void
@@ -594,7 +601,10 @@ rdbuf_esc(PLStream *pls)
     case PLESC_HAS_TEXT:
         rdbuf_text(pls);
 	break;
-    }
+    case PLESC_CLEAR:
+	plP_esc(PLESC_CLEAR,NULL);
+	break;
+		}
 }
 
 /*--------------------------------------------------------------------------*\
@@ -659,7 +669,14 @@ rdbuf_image(PLStream *pls)
     rd_data(pls, dev_iy, sizeof(short) * npts);
     rd_data(pls, dev_z, sizeof(unsigned short) * (nptsX-1)*(nptsY-1));
 
-    plP_image(dev_ix, dev_iy, dev_z, nptsX, nptsY, xmin, ymin, dx, dy, dev_zmin, dev_zmax);
+    /*
+     * COMMENTED OUT by Hezekiah Carty
+     * Commented (hopefullly temporarily) until the dev_fastimg rendering 
+     * path can be updated to support the new plimage internals. In the
+     * meantime this function is not actually used so the issue of how to
+     * update the code to support the new interface can be ignored.
+     */
+    /*plP_image(dev_ix, dev_iy, dev_z, nptsX, nptsY, xmin, ymin, dx, dy, dev_zmin, dev_zmax);*/
 
     free(dev_ix);
     free(dev_iy);
@@ -907,7 +924,7 @@ wr_command(PLStream *pls, U_CHAR c)
         pls->plbuf_buffer_size += pls->plbuf_buffer_grow;
 
         if (pls->verbose)
-            printf("Growing buffer to %d KB\n", pls->plbuf_buffer_size / 1024);
+            printf("Growing buffer to %d KB\n", (int)(pls->plbuf_buffer_size / 1024));
         if ((pls->plbuf_buffer = realloc(pls->plbuf_buffer, pls->plbuf_buffer_size)) == NULL)
             plexit("plbuf wr_data:  Plot buffer grow failed");
     }
@@ -1144,7 +1161,7 @@ void * plbuf_save(PLStream *pls, void *state)
  */
 void plbuf_restore(PLStream *pls, void *state)
 {
-    struct _state *new_state;
+    struct _state *new_state = (struct _state *)state;
 
 #ifdef BUFFERED_FILE
     pls->plbufFile = new_state->save_file;
