@@ -1,4 +1,4 @@
-/* $Id: plcore.c 8208 2008-02-01 21:46:52Z smekal $
+/* $Id: plcore.c 8942 2008-10-21 01:42:57Z airwin $
 
 	Central dispatch facility for PLplot.
 	Also contains the PLplot main data structures, external access
@@ -38,7 +38,11 @@
 #include "plcore.h"
 
 #ifdef ENABLE_DYNDRIVERS
-#include <ltdl.h>
+  #ifndef LTDL_WIN32
+    #include <ltdl.h>
+  #else
+    #include "ltdl_win32.h"
+  #endif
 #endif
 
 /*--------------------------------------------------------------------------*\
@@ -373,8 +377,6 @@ plP_fill(short *x, short *y, PLINT npts)
 #define DEBUG_TEXT
 */
 
-#define hex2dec( a ) isdigit(a) ? a - 48 : (toupper(a) - 65) + 10
-
 /*--------------------------------------------------------------------------*\
  *  int text2num( char *text, char end, PLUNICODE *num)
  *       char *text - pointer to the text to be parsed
@@ -383,29 +385,27 @@ plP_fill(short *x, short *y, PLINT npts)
  *
  *    Function takes a string, which can be either hex or decimal,
  *    and converts it into an PLUNICODE, stopping at either a null,
- *    or the character pointed to by 'end'. It is a bit brain-dead,
- *    and probably should make more checks, but it works.
+ *    or the character pointed to by 'end'. This implementation using
+ *    the C library strtoul replaces the original brain-dead version
+ *    and should be more robust to invalid control strings.
 \*--------------------------------------------------------------------------*/
 
 int text2num( const char *text, char end, PLUNICODE *num)
 {
-  int base=10;
-  unsigned short i=0;
-  *num=0;
 
-  if (text[1]=='x')
-    {
-      base=16;
-      i=2;
-    }
+  char *endptr;
+  char *endptr2;
+  char msgbuf[80];
+
+  *num = strtoul(text,&endptr,0); 
+
+  if (end != endptr[0]) {
+    sprintf(msgbuf,"text2num: invalid control string detected - %c expected",end);
+    plwarn(msgbuf);
+  }
+  
+  return (int)(endptr - text);
 
-  while ((text[i]!=end)&&(text[i]!=0))
-    {
-      *num*=base;
-      *num+=hex2dec(text[i]);
-      i++;
-    }
-  return(i);
 }
 
 /*--------------------------------------------------------------------------*\
@@ -1651,6 +1651,15 @@ c_plinit(void)
     plP_bop();
     plsc->level = 1;
 
+    
+/* The driver options are freed after driver initialisation,
+ * since it is assumed that in this function options are
+ * processed and stored somewhere else. For further driver
+ * initialisations (e.g. copy stream) there are no driver
+ * options defined. */
+
+    plP_FreeDrvOpts();
+
 /* Calculate factor such that the character aspect ratio is preserved
  * when the overall aspect ratio is changed, i.e., if portrait mode is
  * requested (only honored for subset of drivers) or if the aspect ratio
@@ -1786,8 +1795,6 @@ c_plend(void)
     }
     free_mem(dispatch_table);
 
-    plP_FreeDrvOpts();
-
     lib_initialized = 0;
 }
 
@@ -1966,6 +1973,7 @@ pl_cpcolor(PLColor *to, PLColor *from)
     to->r = from->r;
     to->g = from->g;
     to->b = from->b;
+    to->a = from->a;
 }
 
 /*--------------------------------------------------------------------------*\
@@ -2110,7 +2118,7 @@ pllib_devinit()
     plsc->dispatch_table = dispatch_table[plsc->device - 1];
 }
 
-int PLDLLIMPEXP plInBuildTree()
+PLDLLIMPEXP int plInBuildTree()
 {
   static int inited = 0;
   static int inBuildTree = 0;
@@ -2543,7 +2551,11 @@ plLoadDriver(void)
     if (!driver->dlhand)
     {
         char drvspec[ 400 ];
+#ifdef LTDL_WIN32  
+        sprintf( drvspec, "%s", driver->drvnam );
+#else
         sprintf( drvspec, "%s/%s", plGetDrvDir (), driver->drvnam );
+#endif /* LTDL_WIN32 */
 
 	pldebug("plLoadDriver", "Trying to load %s on %s\n",
 		driver->drvnam, drvspec );
@@ -3190,6 +3202,24 @@ c_plgvpw(PLFLT *p_xmin, PLFLT *p_xmax, PLFLT *p_ymin, PLFLT *p_ymax)
     *p_ymax = plsc->vpwyma;
 }
 
+/* Get the viewport boundaries in world coordinates, expanded slightly */
+void
+plP_xgvpw(PLFLT *p_xmin, PLFLT *p_xmax, PLFLT *p_ymin, PLFLT *p_ymax)
+{
+    PLFLT dx, dy;
+
+    dx = (plsc->vpwxma - plsc->vpwxmi) * 1.0e-5;
+    dy = (plsc->vpwyma - plsc->vpwymi) * 1.0e-5;
+
+    /* The plot window is made slightly larger than requested so that */
+    /* the end limits will be on the graph  */
+
+    *p_xmin = plsc->vpwxmi - dx;
+    *p_xmax = plsc->vpwxma + dx;
+    *p_ymin = plsc->vpwymi - dy;
+    *p_ymax = plsc->vpwyma + dy;
+}
+
 /*--------------------------------------------------------------------------*\
  *  These should not be called by the user.
 \*--------------------------------------------------------------------------*/
@@ -3422,13 +3452,30 @@ return(ret);
  *
  * Author: Alessandro Mirone, Nov 2001
  *
- *
+ * Updated by Hezekiah Carty, Mar 2008.
+ *   - Added support for pltr callback
+ *   - Commented out the "dev_fastimg" rendering path
  *
 \*--------------------------------------------------------------------------*/
 
 void
-plP_image(short *x, short *y, unsigned short *z , PLINT nx, PLINT ny, PLFLT xmin, PLFLT ymin, PLFLT dx, PLFLT dy, unsigned short zmin, unsigned short zmax)
+plP_image(PLFLT *z , PLINT nx, PLINT ny, PLFLT xmin, PLFLT ymin, PLFLT dx, PLFLT dy,
+          void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer), PLPointer pltr_data)
 {
+  plsc->page_status = DRAWING;
+
+  plimageslow(z, nx, ny, xmin, ymin, dx, dy, pltr, pltr_data);
+
+  /*
+   * COMMENTED OUT by Hezekiah Carty, March 2008
+   * The current dev_fastimg rendering method does not work as-is with
+   * the plimagefr coordinate transform support.
+   * This is hopefully temporary, until the dev_fastimg rendering
+   * path can be updated to work with the new plimage internals.
+   * Until then, all plimage* rendering is done by the plimageslow
+   * rendering path.
+   */
+#if 0   /* BEGIN dev_fastimg COMMENT */  
   PLINT i, npts;
   short *xscl, *yscl;
   int   plbuf_write;
@@ -3494,4 +3541,5 @@ plP_image(short *x, short *y, unsigned short *z , PLINT nx, PLINT ny, PLFLT xmin
     grimage(x, y, z, nx, ny );
   }
   plsc->plbuf_write = plbuf_write;
+#endif  /* END dev_fastimg COMMENT */
 }
