@@ -1,4 +1,4 @@
-/* $Id: plctrl.c 8156 2008-01-22 13:57:53Z andrewross $
+/* $Id: plctrl.c 9110 2008-12-15 09:50:50Z andrewross $
 
 	Misc. control routines, like begin, end, exit, change graphics/text
 	mode, change color.  Includes some spillage from plcore.c.  If you
@@ -50,6 +50,9 @@
 #include <errno.h>
 #endif
 
+/* Random number generator (Mersenne Twister) */
+#include "mt19937ar.h"
+
 /* Static functions */
 
 /* Used by any external init code to suggest a path */
@@ -373,6 +376,7 @@ c_plscmap0(PLINT *r, PLINT *g, PLINT *b, PLINT ncol0)
 	plsc->cmap0[i].r = r[i];
 	plsc->cmap0[i].g = g[i];
 	plsc->cmap0[i].b = b[i];
+	plsc->cmap0[i].a = 1.0;
     }
 
     if (plsc->level > 0)
@@ -1859,13 +1863,15 @@ plP_getmember(PLStream *pls)
 /*--------------------------------------------------------------------------*\
  * plP_sfnam()
  *
- * Sets up file name & family stem name.
- * Reserve some extra space (5 chars) to hold an optional member number.
+ * Sets up file name (with "%n" removed if present) & family stem name.
+ * Reserve some extra space (10 chars) to hold an optional member number.
 \*--------------------------------------------------------------------------*/
 
 void
 plP_sfnam(PLStream *pls, const char *fnam)
 {
+    char prefix[256];
+    char* suffix;
     pls->OutFile = NULL;
 
     if (pls->FileName != NULL)
@@ -1876,7 +1882,15 @@ plP_sfnam(PLStream *pls, const char *fnam)
         plexit("plP_sfnam: Insufficient memory");
       }
 
-    strcpy(pls->FileName, fnam);
+    suffix = strstr (fnam, "%n");
+
+    if (suffix == NULL)
+      strcpy(pls->FileName, fnam);
+    else {
+      strncpy (prefix, fnam, 256);
+      prefix [suffix - fnam] = 0;
+      sprintf (pls->FileName, "%s%s", prefix, suffix + 2);
+    }
 
     if (pls->BaseName != NULL)
 	free((void *) pls->BaseName);
@@ -1927,10 +1941,15 @@ plGetFam(PLStream *pls)
     PLFLT xpmm_loc, ypmm_loc;
     if (pls->family) {
 	if (pls->bytecnt > pls->bytemax || pls->famadv) {
+	    PLINT local_page_status = pls->page_status;
 	    plP_tidy();
 	    pls->member += pls->finc;
 	    pls->famadv = 0;
 	    plP_init();
+	    /* Restore page status (normally AT_BOP) that was changed
+	     * to AT_EOP by plP_init. */
+	    pls->page_status = local_page_status;
+	    
 	   /* Apply compensating factor to original xpmm and ypmm so that
 	    * character aspect ratio is preserved when overall aspect ratio
 	    * is changed. */
@@ -2034,7 +2053,7 @@ plGetInt(const char *s)
     char line[256];
 
     while (i++ < 10) {
-	fprintf(stdout, s);
+	fputs(s, stdout);
 	plio_fgets(line, sizeof(line), stdin);
 
 #ifdef MSDOS
@@ -2065,7 +2084,7 @@ plGetFlt(const char *s)
     char line[256];
 
     while (i++ < 10) {
-	fprintf(stdout, s);
+	fputs(s, stdout);
 	plio_fgets(line, sizeof(line), stdin);
 
 #ifdef MSDOS
@@ -2101,3 +2120,72 @@ plstrdup(const char *src)
 
     return dest;
 }
+
+#ifndef PL_HAVE_SNPRINTF
+/*--------------------------------------------------------------------------*\
+ * plsnprintf()
+ *
+ * Dummy function for snprintf(). This function just calls
+ * the unsafe function ignoring the string size. This function will
+ * rarely be needed if ever.
+\*--------------------------------------------------------------------------*/
+
+int 
+plsnprintf(char *buffer, int n, const char *format, ...)
+{
+  int ret;
+
+  va_list args;             
+  va_start(args, format);
+	ret=vsprintf(buffer, fmt, args);
+  va_end( argptr );
+  
+  return ret;
+}
+
+/*--------------------------------------------------------------------------*\
+ * plsnscanf()
+ *
+ * Dummy function for snscanf(). This function just calls
+ * the unsafe function ignoring the string size. This function will
+ * rarely be needed if ever.
+\*--------------------------------------------------------------------------*/
+
+int
+plsnscanf( const char *buffer, int n, const char *format, ... )
+{
+  int ret;
+  
+  va_list argptr;             
+  va_start(argptr, format);
+	ret=vsscanf(buffer, fmt, args);  
+  va_end(argptr);
+  
+  return ret;
+}
+
+#endif /* PL_HAVE_SNPRINTF */
+
+/*--------------------------------------------------------------------------*\
+ * plseed()
+ *
+ * Set the seed for the random number generator included.
+\*--------------------------------------------------------------------------*/
+
+void
+c_plseed(unsigned int s)
+{
+  init_genrand(s);
+}
+
+/*--------------------------------------------------------------------------*\
+ * plrandd()
+ *
+ * Returns a random number on [0,1]-interval.
+\*--------------------------------------------------------------------------*/
+
+PLFLT
+c_plrandd(void)
+{
+  return (PLFLT)(genrand_real1());
+}
