@@ -1,4 +1,4 @@
-/* $Id: pldtik.c 8082 2007-12-12 15:44:17Z andrewross $
+/* $Id: pldtik.c 9014 2008-11-21 21:56:30Z smekal $
 
 	Determines tick spacing and mode (fixed or floating) of
 	numeric axis labels.
@@ -39,7 +39,7 @@ pldtik(PLFLT vmin, PLFLT vmax, PLFLT *tick, PLINT *nsubt, PLBOOL ld)
 {
     PLFLT t1, t2, tick_reasonable;
     PLINT np, ns;
-    PLFLT diff, factor;
+    PLFLT factor;
 
 
     if (ld) {
@@ -119,8 +119,14 @@ pldtfac(PLFLT vmin, PLFLT vmax, PLFLT *factor, PLFLT *start) {
   diff = vmax - vmin;
 
   if (start != NULL) {
+    struct tm* tmp;
+    
     t = (time_t) vmin;
-    tm = *gmtime(&t);
+    if(!(tmp=gmtime(&t))) {
+      plabort("pldtfac: gmtime() returned an invalid value");
+      return;
+    }
+    tm = *tmp;
     t2 = mktime(&tm);
     /* Arg! This is because mktime is in local time and we need to 
        correct for the offset. C time handling really is broken... */
