@@ -1,4 +1,4 @@
-/* $Id: plfreetype.c 7801 2007-08-15 18:50:21Z andrewross $
+/* $Id: plfreetype.c 8981 2008-10-29 15:13:39Z andrewross $
  *
  * Copyright (C) 2002, 2004, 2005  Andrew Roach
  * Copyright (C) 2002  Maurice LeBrun
@@ -94,7 +94,7 @@
 #define FT_Data _FT_Data_
 
 /* Font lookup table that is constructed in plD_FreeType_init*/
-FCI_to_FontName_Table FontLookup[N_TrueTypeLookup];
+PLDLLIMPEXP_DATA(FCI_to_FontName_Table) FontLookup[N_TrueTypeLookup];
 /*              TOP LEVEL DEFINES       */
 
 /*  Freetype lets you set the text size absolutely. It also takes into
@@ -116,7 +116,7 @@ FCI_to_FontName_Table FontLookup[N_TrueTypeLookup];
  *  Some debugging macros
 \*--------------------------------------------------------------------------*/
 
-#define Debug5(a,b,c,d,e) do {if (pls->debug){fprintf(stderr,a,b,c,d,e);}}while(0)
+#define Debug6(a,b,c,d,e,f) do {if (pls->debug){fprintf(stderr,a,b,c,d,e,f);}}while(0)
 
 
 /*              FUNCTION PROTOTYPES    */
@@ -461,10 +461,11 @@ FT_PlotChar(PLStream *pls, FT_Data *FT, FT_GlyphSlot slot,
 	    for (k=0;k<n;k++) {
 		bittest=128;
 		for (j=0;j<8;j++) {
-		    if ((bittest&(unsigned char)slot->bitmap.buffer[(i*n)+k])==bittest)
+		    if ((bittest&(unsigned char)slot->bitmap.buffer[(i*n)+k])==bittest) {
 			xx = x+(k*8)+j;
 			if ( (xx >= clipxmin) && (xx <= clipxmax) )
 			  FT->pixel(pls, xx, y+i);
+                    }
 		    bittest>>=1;
 		}
             }
@@ -815,7 +816,8 @@ if ((args->string!=NULL)||(args->unicode_array_len>0))
 
 /*  this will help work out underlining and overlining*/
 
-    Debug5("%d %d %d %d;",FT->face->underline_position>>6,
+    Debug6("%s %d %d %d %d\n","plD_render_freetype_text:",
+	   FT->face->underline_position>>6,
 	   FT->face->descender>>6,
 	   FT->face->ascender>>6,
 	   ((FT->face->underline_position*-1)+FT->face->ascender)>>6);
@@ -1057,7 +1059,8 @@ void plD_FreeType_Destroy(PLStream *pls)
 
     if (FT) {
 	if ((FT->smooth_text==1)&&(FT->BLENDED_ANTIALIASING==0)) plscmap0n(FT->ncol0_org);
-
+        if (FT->textbuf)
+          free(FT->textbuf);
 	FT_Done_Library(FT->library);
 	free(pls->FT);
 	pls->FT=NULL;
