@@ -1,4 +1,4 @@
-/* $Id: plstripc.c 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: plstripc.c 9275 2009-01-07 22:56:20Z airwin $
  *
  * Plots a simple stripchart.
  *
@@ -74,11 +74,6 @@ c_plstripc( PLINT *id, const char *xspec, const char *yspec,
 {
     int i;
 
-    if (!plsc->termin) {
-	plabort("Stripchart plot requires a terminal output device");
-	return;
-    }
-
 /* Get a free strip id and allocate it */
 
     for (i = 0; i < MAX_STRIPC; i++)
