@@ -1,4 +1,4 @@
-/* $Id: pltick.c 6212 2005-04-27 06:44:27Z rlaboiss $
+/* $Id: pltick.c 9115 2008-12-15 11:58:19Z andrewross $
 
 	Routines for drawing error bars and tick marks.
 
@@ -32,15 +32,8 @@
 void
 plxtik(PLINT x, PLINT y, PLINT below, PLINT above)
 {
-    plP_draphy(x, y);
-
-    if (below != 0)
-	plP_draphy(x, y - below);
-
-    if (above != 0)
-	plP_draphy(x, y + above);
-
-    plP_draphy(x, y);
+    plP_movphy(x, y-below);
+    plP_draphy(x, y+above);
 }
 
 /*----------------------------------------------------------------------*\
@@ -52,15 +45,8 @@ plxtik(PLINT x, PLINT y, PLINT below, PLINT above)
 void
 plytik(PLINT x, PLINT y, PLINT left, PLINT right)
 {
-    plP_draphy(x, y);
-
-    if (left != 0)
-	plP_draphy(x - left, y);
-
-    if (right != 0)
-	plP_draphy(x + right, y);
-
-    plP_draphy(x, y);
+    plP_movphy(x-left, y);
+    plP_draphy(x+right, y);
 }
 
 /*----------------------------------------------------------------------*\
@@ -73,9 +59,8 @@ plytik(PLINT x, PLINT y, PLINT left, PLINT right)
 void
 plstik(PLFLT mx, PLFLT my, PLFLT dx, PLFLT dy)
 {
-    plP_draphy(plP_mmpcx(mx), plP_mmpcy(my));
+    plP_movphy(plP_mmpcx(mx), plP_mmpcy(my));
     plP_draphy(plP_mmpcx((PLFLT) (mx + dx)), plP_mmpcy((PLFLT) (my + dy)));
-    plP_draphy(plP_mmpcx(mx), plP_mmpcy(my));
 }
 
 /*----------------------------------------------------------------------*\
@@ -90,8 +75,8 @@ plerx1(PLFLT xmin, PLFLT xmax, PLFLT y)
     PLINT yminor;
 
     yminor = MAX(1.0, plsc->minht * plsc->ypmm);
-    plP_movwor(xmin, y);
     plxtik(plP_wcpcx(xmin), plP_wcpcy(y), yminor, yminor);
+    plP_movwor(xmin, y);
     plP_drawor(xmax, y);
     plxtik(plP_wcpcx(xmax), plP_wcpcy(y), yminor, yminor);
 }
@@ -108,8 +93,8 @@ plery1(PLFLT x, PLFLT ymin, PLFLT ymax)
     PLINT xminor;
 
     xminor = MAX(1.0, plsc->minht * plsc->xpmm);
-    plP_movwor(x, ymin);
     plytik(plP_wcpcx(x), plP_wcpcy(ymin), xminor, xminor);
+    plP_movwor(x, ymin);
     plP_drawor(x, ymax);
     plytik(plP_wcpcx(x), plP_wcpcy(ymax), xminor, xminor);
 }
