@@ -1,4 +1,4 @@
-/* $Id: plvect.c 7349 2007-02-04 05:45:38Z aroach $
+/* $Id: plvect.c 8269 2008-03-11 10:14:36Z andrewross $
 
 	Vector plotting routines.
 
@@ -30,114 +30,10 @@
 
 static void plP_plotvect(PLFLT x, PLFLT y, PLFLT u, PLFLT v, PLFLT scale);
 
-/*--------------------------------------------------------------------------*\
- * void c_plarrows()
- *
- * simple arrow plotter
- * copyright 1993 Wesley Ebisuzaki
- *
- * an arrow is defined by its location (x, y) and its direction (u, v)
- *
- * inputs:
- *   u[i], v[i]      arrow's horizontal and vertical projection
- *   x[i], y[i]      arrow's location (world coordinates)
- *   n               number of arrows to draw
- *   scale           > 0  scaling factor for arrows
- *                   0    default scaling factor
- *                   < 0  default scaling factor * (-scale)
- *   dx, dy          distance between arrows
- *                   used when calculating the default arrow scaling
- *                   so that arrows don't overlap
- *
-\*--------------------------------------------------------------------------*/
-
-#define SCALE0 2.0
-
-/* definition of original arrow: 2 line segments */
-
-static PLFLT arrow_x[4] = {0.5, -0.5, -0.27, -0.5};
-static PLFLT arrow_y[4] = {0.0, 0.0, 0.0, 0.20};
-
-void
-c_plarrows(PLFLT *u, PLFLT *v, PLFLT *x, PLFLT *y, PLINT n,
-	 PLFLT scale, PLFLT dx, PLFLT dy)
-{
-    PLFLT uu, vv;
-    PLINT i, j, npts = 4;
-    PLINT px0, py0, dpx, dpy;
-    PLINT a_x[4], a_y[4];
-    PLFLT max_u, max_v;
-    double t;
-
-    if (n <= 0) return;
-
-    if (scale <= 0.0) {
-
-    /* automatic scaling */
-    /* find max / min values of data */
-
-	max_u = u[0];
-	max_v = v[0];
-	for (i = 1; i < n; i++) {
-	    t = fabs((double) u[i]);
-	    max_u = t > max_u ? t : max_u;
-	    t = fabs((double) v[i]);
-	    max_v = t > max_v ? t : max_v;
-	}
-
-    /* measure distance in grid boxs */
-
-	max_u = max_u / fabs( (double) dx);
-	max_v = max_v / fabs( (double) dy);
-
-	t = (max_u > max_v ? max_u : max_v);
-	t = SCALE0 / t;
-	if (scale < 0) {
-	    scale = -scale * t;
-	}
-	else {
-	    scale = t;
-	}
-    }
-    pldebug("plarrows", "scale factor=%lf n=%d\n", scale,n);
-
-    for (i = 0; i < n; i++) {
-	uu = scale * u[i];
-	vv = scale * v[i];
-	if (uu == 0.0 && uu == 0.0) continue;
-
-    /* conversion to physical coordinates */
-
-	px0 = plP_wcpcx(x[i]);
-	py0 = plP_wcpcy(y[i]);
-
-	pldebug("plarrows", "%f %f %d %d\n",x[i],y[i],px0,py0);
-
-	dpx = plP_wcpcx(x[i] + 0.5*uu) - px0;
-	dpy = plP_wcpcy(y[i] + 0.5*vv) - py0;
-
-    /* transform arrow -> a */
-
-	for (j = 0; j < npts; j++) {
-	    a_x[j] = arrow_x[j] * dpx -
-		arrow_y[j] * dpy + px0;
-	    a_y[j] = arrow_x[j] * dpy +
-		arrow_y[j] * dpx + py0;
-	}
-
-    /* draw the arrow */
-	plP_movphy(a_x[0], a_y[0]);
-	plP_draphy(a_x[1], a_y[1]);
-	plP_movphy(a_x[2], a_y[2]);
-	plP_draphy(a_x[3], a_y[3]);
-    }
-
-}
-
 /*--------------------------------------------------------------------------*\
  * void c_plsvect()
  *
- * Set the style of the arrow used by plarrows
+ * Set the style of the arrow used by plvect
 \*--------------------------------------------------------------------------*/
 
 void
@@ -239,7 +135,7 @@ void plfvect(PLFLT (*plf2eval) (PLINT, PLINT, PLPointer),
 	
     /* Calculate apropriate scaling if necessary */
     if (scale <= 0.0 ) {
-        if (nx <= 1 && ny <= 1) {
+      if (nx <= 1 && ny <= 1) {
             fprintf(stderr,"plfvect: not enough points for autoscaling\n");
             return;
         }
